@@ -117,7 +117,7 @@ void ActivityHandler::onMainTimerTick()
     }
 
 
-    foreach (QVariant mapVariant, m_activityDataList)
+    foreach (const QVariant mapVariant, m_activityDataList)
     {
         bool shouldDoIt = true; // Until proven guilty
 
@@ -164,7 +164,6 @@ void ActivityHandler::onMainTimerTick()
             minDate.setDate(dateNow.year(), minDate.month(), minDate.day());
             QDate maxDate = map.value("maxDate").toDate();
             maxDate.setDate(dateNow.year(), maxDate.month(), maxDate.day());
-            qDebug() << minDate << dateNow << maxDate;
 
             if (minDate <= maxDate)    // Cases such as April to September,
             {                          // including cases like 15/Mar-15/Mar
@@ -240,9 +239,13 @@ void ActivityHandler::onMainTimerTick()
                                      + " [" + durationString + "]");
 
 
-            QString timeRange = timeNow.toString(Qt::SystemLocaleShortDate)
-                                + QStringLiteral(" ~ ")
-                                + endTime.toString(Qt::SystemLocaleShortDate);
+            const QString timeRange = timeNow.toString(Qt::SystemLocaleShortDate)
+                                      + QStringLiteral(" ~ ")
+                                      + endTime.toString(Qt::SystemLocaleShortDate);
+
+            m_globalObject->setAvailability(map.value("availability").toInt());
+            m_globalObject->setReactionTime(map.value("minReaction").toInt(),
+                                            map.value("maxReaction").toInt());
 
             m_globalObject->notifyActivityChange(m_activityInProgress, timeRange);
 
@@ -253,7 +256,7 @@ void ActivityHandler::onMainTimerTick()
             m_oldStatusMessage = presence.statusText();
 
             presence.setAvailableStatusType(this->presenceFromIndex(map.value("statusType")
-                                                                        .toInt()));
+                                                                       .toInt()));
 
             QString statusMsg = Helpers::randomString(map.value("statusMessages")
                                                          .toStringList());
@@ -273,19 +276,34 @@ void ActivityHandler::onMainTimerTick()
                 // Send messages to configured recipients about the activity
                 m_allRecipientJids.clear();
 
+
+                // Get a list of all fully-joined rooms that may be recipients...
+                QStringList allAllowedRooms = m_globalObject->getFullyJoinedRooms();
+
+                // ...and remove the ones that don't allow 'casual speak'
+                const QList<QXmppMucRoom *> allMucObjects = m_mucManager->rooms();
+                foreach (const QXmppMucRoom *muc, allMucObjects)
+                {
+                    if (muc->property("allowCasualSpeak").toBool() == false)
+                    {
+                        allAllowedRooms.removeAll(muc->jid());
+                    }
+                }
+
+
                 const int msgToRooms = map.value("msgToRooms").toInt();
                 if (msgToRooms == 0)       // All rooms
                 {
-                    m_allRecipientJids = m_globalObject->getJoinedRooms();
+                    m_allRecipientJids = allAllowedRooms;
                 }
                 else if (msgToRooms == 1)  // Several rooms
                 {
-                    m_allRecipientJids = Helpers::someStrings(m_globalObject->getJoinedRooms(),
+                    m_allRecipientJids = Helpers::someStrings(allAllowedRooms,
                                                               50);
                 }
                 else if (msgToRooms == 2)  // A few rooms
                 {
-                    m_allRecipientJids = Helpers::someStrings(m_globalObject->getJoinedRooms(),
+                    m_allRecipientJids = Helpers::someStrings(allAllowedRooms,
                                                               20);
                 }
 
@@ -302,7 +320,7 @@ void ActivityHandler::onMainTimerTick()
                  * configured room, but are not in the fully-joined-rooms list
                  *
                  */
-                foreach (QString specificJid, allSpecificJids)
+                foreach (const QString specificJid, allSpecificJids)
                 {
                     if (m_globalObject->isRoomConfigured(specificJid))
                     {
@@ -330,12 +348,14 @@ void ActivityHandler::onMainTimerTick()
                     }
                 }
 
+                // Specific JIDs or active chats could introduce duplicates
+                m_allRecipientJids.removeDuplicates(); // FIXME: a bit overkill
 
                 // Proceed to send the before-activity message
                 const QStringList messagesBefore = map.value("msgBefore")
                                                       .toStringList();
                 QString msgBefore;
-                foreach (QString recipient, m_allRecipientJids)
+                foreach (const QString recipient, m_allRecipientJids)
                 {
                     msgBefore = Helpers::randomString(messagesBefore);
                     msgBefore = m_variableParser->getParsed(msgBefore);
@@ -362,6 +382,9 @@ void ActivityHandler::activityFinished()
                              .arg("<b>" + m_activityInProgress + "</b>"));
 
     m_activityInProgress.clear();
+
+    m_globalObject->setAvailability(99);    // FIXME TMP HARDCODED
+    m_globalObject->setReactionTime(1, 10); // FIXME TMP HARDCODED
     m_globalObject->notifyActivityChange("[ " + tr("None",
                                                    "Regarding an activity")
                                          + " ]",
@@ -377,7 +400,7 @@ void ActivityHandler::activityFinished()
 
         // Send messages to configured recipients, about the end of the activity
         QString msgAfter;
-        foreach (QString recipient, m_allRecipientJids)
+        foreach (const QString recipient, m_allRecipientJids)
         {
             msgAfter = Helpers::randomString(m_messagesAfter);
             msgAfter = m_variableParser->getParsed(msgAfter);
