@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -42,7 +42,8 @@ class ActivityHandler : public QObject
     Q_OBJECT
 
 public:
-    explicit ActivityHandler(GlobalObject *globalObject, QObject *parent = 0);
+    explicit ActivityHandler(GlobalObject *globalObject,
+                             QObject *parent = nullptr);
     ~ActivityHandler();
 
     void setActivityData(QVariantList dataList);
