@@ -28,8 +28,11 @@ ActivityModule::ActivityModule(ActivityHandler *activityHandler,
     m_globalObject = globalObject;
     m_activityHandler = activityHandler;
 
+    m_variableParser = m_globalObject->getVariableParser();
+
+
     m_dataFile = new DataFile(m_globalObject->getDataDirectory()
-                              + "/activities.axb",
+                              + QStringLiteral("/activities.axb"),
                               this);
 
 
@@ -105,7 +108,9 @@ ActivityModule::ActivityModule(ActivityHandler *activityHandler,
     m_statusTypeCombobox->addItem(tr("Extended Away"));
     m_statusTypeCombobox->addItem(tr("Do not Disturb"));
 
-    m_statusMessagesListWidget = new StringListWidget(false, this);
+    m_statusMessagesListWidget = new StringListWidget(StringListWidget::BasicList,
+                                                      this);
+    m_statusMessagesListWidget->setCheckSyntaxEnabled(m_variableParser);
 
 
     m_availabilitySpinbox = new QSpinBox(this);
@@ -121,10 +126,17 @@ ActivityModule::ActivityModule(ActivityHandler *activityHandler,
     m_maxReactionSpinbox->setSuffix(" " + tr("seconds"));
 
 
-    m_descriptionListWidget = new StringListWidget(false, this);
+    m_descriptionListWidget = new StringListWidget(StringListWidget::StringsWithTags,
+                                                   this);
+    m_descriptionListWidget->setCheckSyntaxEnabled(m_variableParser);
 
-    m_msgBeforeListWidget = new StringListWidget(false, this);
-    m_msgAfterListWidget = new StringListWidget(false, this);
+    m_msgBeforeListWidget = new StringListWidget(StringListWidget::StringsWithTags,
+                                                 this);
+    m_msgBeforeListWidget->setCheckSyntaxEnabled(m_variableParser);
+
+    m_msgAfterListWidget = new StringListWidget(StringListWidget::StringsWithTags,
+                                                this);
+    m_msgAfterListWidget->setCheckSyntaxEnabled(m_variableParser);
 
 
     // Send messsages to:
@@ -202,25 +214,25 @@ ActivityModule::ActivityModule(ActivityHandler *activityHandler,
     m_msgRecipientsLayout->addLayout(m_recipientsBottomLayout);
 
 
-    this->formLayout = new QFormLayout();
-    formLayout->addRow(tr("Name"),                  m_nameLineEdit);
-    formLayout->addRow(tr("Maximum Times Per Day"), m_timesPerDaySpinbox);
-    formLayout->addRow(tr("Probability"),           m_probabilitySpinbox);
-    formLayout->addRow(tr("Time Range"),            m_timeLayout);
-    formLayout->addRow(tr("Date Range"),            m_dateLayout);
-    formLayout->addRow(tr("Duration"),              m_durationLayout);
-    formLayout->addRow(tr("Set Status Type"),       m_statusTypeCombobox);
-    formLayout->addRow(tr("Status Messages"),       m_statusMessagesListWidget);
-    formLayout->addRow(tr("Availability"),          m_availabilitySpinbox);
-    formLayout->addRow(tr("Reaction Time"),         m_reactionLayout);
-    formLayout->addRow(tr("Descriptions"),          m_descriptionListWidget);
-    formLayout->addRow(tr("Messages Before"),       m_msgBeforeListWidget);
-    formLayout->addRow(tr("Messages Afterwards"),   m_msgAfterListWidget);
-    formLayout->addRow(tr("Send Messages To"),      m_msgRecipientsLayout);
+    m_formLayout = new QFormLayout();
+    m_formLayout->addRow(tr("Name"),                  m_nameLineEdit);
+    m_formLayout->addRow(tr("Maximum Times Per Day"), m_timesPerDaySpinbox);
+    m_formLayout->addRow(tr("Probability"),           m_probabilitySpinbox);
+    m_formLayout->addRow(tr("Time Range"),            m_timeLayout);
+    m_formLayout->addRow(tr("Date Range"),            m_dateLayout);
+    m_formLayout->addRow(tr("Duration"),              m_durationLayout);
+    m_formLayout->addRow(tr("Set Status Type"),       m_statusTypeCombobox);
+    m_formLayout->addRow(tr("Status Messages"),       m_statusMessagesListWidget);
+    m_formLayout->addRow(tr("Availability"),          m_availabilitySpinbox);
+    m_formLayout->addRow(tr("Reaction Time"),         m_reactionLayout);
+    m_formLayout->addRow(tr("Descriptions"),          m_descriptionListWidget);
+    m_formLayout->addRow(tr("Messages Before"),       m_msgBeforeListWidget);
+    m_formLayout->addRow(tr("Messages Afterwards"),   m_msgAfterListWidget);
+    m_formLayout->addRow(tr("Send Messages To"),      m_msgRecipientsLayout);
 
 
     m_rightWidget = new QWidget(this);
-    m_rightWidget->setLayout(formLayout);
+    m_rightWidget->setLayout(m_formLayout);
 
     m_rightScrollArea = new QScrollArea(this);
     m_rightScrollArea->setContentsMargins(1, 1, 1, 1);
@@ -240,7 +252,7 @@ ActivityModule::ActivityModule(ActivityHandler *activityHandler,
 
 
     m_removeActivityButton->setDisabled(true);
-    m_rightScrollArea->setDisabled(true);
+    m_rightWidget->setDisabled(true);
     m_saveActivityButton->setDisabled(true);
 
     this->loadActivities();
@@ -261,7 +273,7 @@ void ActivityModule::loadActivities()
 {
     const QVariantList activityDataList = m_dataFile->loadData();
 
-    foreach (QVariant listItem, activityDataList)
+    foreach (const QVariant listItem, activityDataList)
     {
         const QVariantMap map = listItem.toMap();
         QListWidgetItem *item = new QListWidgetItem();
@@ -390,7 +402,7 @@ void ActivityModule::removeActivity()
     if (m_activityListWidget->count() == 0) // No activities left
     {
         m_removeActivityButton->setDisabled(true);
-        m_rightScrollArea->setDisabled(true);
+        m_rightWidget->setDisabled(true);
         m_saveActivityButton->setDisabled(true);
     }
 }
@@ -441,7 +453,7 @@ void ActivityModule::onActivitySelected(int row)
 
 
     m_removeActivityButton->setEnabled(true);
-    m_rightScrollArea->setEnabled(true);
+    m_rightWidget->setEnabled(true);
 }
 
 
