@@ -43,6 +43,7 @@
 #include "globalobject.h"
 #include "activityhandler.h"
 #include "stringlistwidget.h"
+#include "variableparser.h"
 #include "datafile.h"
 
 
@@ -90,7 +91,7 @@ private:
     QScrollArea *m_rightScrollArea;
     QWidget *m_rightWidget;
     QVBoxLayout *m_rightLayout;
-    QFormLayout *formLayout;    
+    QFormLayout *m_formLayout;
 
     QLineEdit *m_nameLineEdit;
 
@@ -136,6 +137,7 @@ private:
 
     DataFile *m_dataFile;
     ActivityHandler *m_activityHandler;
+    VariableParser *m_variableParser;
     GlobalObject *m_globalObject;
 };
 
