@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -26,6 +26,8 @@ ChatModule::ChatModule(GlobalObject *globalObject,
     m_globalObject = globalObject;
     connect(m_globalObject, &GlobalObject::privateMessageSent,
             this, &ChatModule::addOutgoingMessage);
+    connect(m_globalObject, &GlobalObject::conversationTabRequested,
+            this, &ChatModule::startConversation);
 
     m_xmppClient = m_globalObject->getXmppClient();
 
@@ -40,6 +42,14 @@ ChatModule::ChatModule(GlobalObject *globalObject,
     connect(m_tabWidget, &QTabWidget::tabCloseRequested,
             this, &ChatModule::closeTab);
 
+    m_noChatsLabel = new QLabel("<br /><br /><br />"
+                                "<h2>" + tr("There are no active chats")
+                                + "</h2>"
+                                "<br /><br /><br />",
+                                this);
+    m_noChatsLabel->setAlignment(Qt::AlignCenter);
+
+
     m_closeTabAction = new QAction(this);
     m_closeTabAction->setShortcut(QKeySequence("Ctrl+W"));
     connect(m_closeTabAction, &QAction::triggered,
@@ -49,6 +59,7 @@ ChatModule::ChatModule(GlobalObject *globalObject,
 
     m_mainLayout = new QVBoxLayout();
     m_mainLayout->setContentsMargins(0, 0, 0, 0);
+    m_mainLayout->addWidget(m_noChatsLabel);
     m_mainLayout->addWidget(m_tabWidget);
     this->setLayout(m_mainLayout);
 
@@ -76,7 +87,7 @@ void ChatModule::setTabTitle(int tabNumber, QString name, int unread)
  * Find or create a new tab with a ChatWidget for a given JID
  *
  */
-int ChatModule::tabForJid(QString jid)
+int ChatModule::tabForJid(QString jid, int messageDirection)
 {
     const QString bareJid = jid.split("/").first();
 
@@ -145,21 +156,29 @@ int ChatModule::tabForJid(QString jid)
 
         // It's important to connect() *after* the tab has been added
         connect(chatWidget, &ChatWidget::messagesRead,
-                this, &ChatModule::updateTabTitle);
+                this, &ChatModule::resetTabTitle);
 
 
-
-        m_globalObject->addToLog(tr("Chat started by %1.",
-                                    "%1 = A nickname").arg(jid));
-
-        if (m_globalObject->getNotifyNewChats())
+        // Log and notify only if started by contacts, not by us
+        if (messageDirection == ChatModule::MessageIncoming)
         {
-            m_globalObject->showNotification(tr("New chat"),
-                                             tr("A new chat was started by %1.")
-                                             .arg(jid));
+            m_globalObject->addToLog(tr("Chat started by %1.",
+                                        "%1 = A nickname")
+                                     .arg("'<b>" + jid + "</b>'"));
+
+            if (m_globalObject->getNotifyNewChats())
+            {
+                m_globalObject->showNotification(tr("New chat"),
+                                                 tr("A new chat was started "
+                                                    "by %1.")
+                                                 .arg(jid.toHtmlEscaped()));
+            }
         }
 
         // TODO: optional email/XMPP notification for this event
+
+        // Hide message about no active chats
+        m_noChatsLabel->hide();
     }
 
 
@@ -176,7 +195,8 @@ int ChatModule::tabForJid(QString jid)
 
 void ChatModule::addChatTab(QXmppMessage message)
 {
-    const int tabNumber = this->tabForJid(message.from());
+    const int tabNumber = this->tabForJid(message.from(),
+                                          ChatModule::MessageIncoming);
 
     ChatWidget *currentChatWidget = m_openedChats.at(tabNumber);
     currentChatWidget->appendMessage(message);
@@ -195,26 +215,41 @@ void ChatModule::addChatTab(QXmppMessage message)
 }
 
 
-void ChatModule::updateTabTitle(int count)
+void ChatModule::resetTabTitle(QString chatTitle, int count)
 {
     m_unreadCount -= count;
-    emit unreadCountChanged(m_unreadCount);
+    emit unreadCountChanged(m_unreadCount); // Update total chats unread count
 
-    const int currentTab = m_tabWidget->currentIndex();
-
-    this->setTabTitle(currentTab,
-                      m_openedChats.at(currentTab)->getChatTitle(),
-                      m_openedChats.at(currentTab)->getUnreadCount());
+    // Find tab by raw title, and reset title
+    for (int currentTab = 0;  currentTab < m_tabWidget->count(); ++currentTab)
+    {
+        if (m_openedChats.at(currentTab)->getChatTitle() == chatTitle)
+        {
+            this->setTabTitle(currentTab,
+                              chatTitle,
+                              0); // Clearly, no more unread remain in that tab
+            break;
+        }
+    }
 }
 
 
 void ChatModule::closeTab(int tabIndex)
 {
+    // Update unread counts: tab can be closed without activating it previously
+    m_unreadCount -= m_openedChats.at(tabIndex)->getUnreadCount();
+    emit unreadCountChanged(m_unreadCount);
+
     // It's important to remove the tab before deleting the widget on it
     m_tabWidget->removeTab(tabIndex);
 
     m_openedChats.at(tabIndex)->deleteLater();
     m_openedChats.removeAt(tabIndex);
+
+    if (m_openedChats.count() < 1)
+    {
+        m_noChatsLabel->show();
+    }
 }
 
 void ChatModule::closeCurrentTab()
@@ -231,7 +266,7 @@ void ChatModule::addOutgoingMessage(QString toJid, QString message)
 {
     qDebug() << "Sending private message to" << toJid << ": " << message;
 
-    const int tabNumber = this->tabForJid(toJid);
+    const int tabNumber = this->tabForJid(toJid, ChatModule::MessageOutgoing);
 
     ChatWidget *currentChatWidget = m_openedChats.at(tabNumber);
     currentChatWidget->appendOutgoingMessage(message);
@@ -243,3 +278,12 @@ void ChatModule::addOutgoingMessage(QString toJid, QString message)
                       currentChatWidget->getUnreadCount());
 }
 
+
+void ChatModule::startConversation(QString toJid)
+{
+    qDebug() << "Starting conversation with" << toJid;
+
+    const int tabNumber = this->tabForJid(toJid, ChatModule::MessageOutgoing);
+    m_tabWidget->setCurrentIndex(tabNumber);
+    m_openedChats.at(tabNumber)->focusLineEdit();
+}
