@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -41,11 +41,17 @@ class ChatModule : public QWidget
     Q_OBJECT
 
 public:
-    explicit ChatModule(GlobalObject *globalObject, QWidget *parent = 0);
+    explicit ChatModule(GlobalObject *globalObject, QWidget *parent = nullptr);
     ~ChatModule();
 
     void setTabTitle(int tabNumber, QString name, int unread);
-    int tabForJid(QString jid);
+    int tabForJid(QString jid, int messageDirection);
+
+    enum MessageDirection
+    {
+        MessageIncoming,
+        MessageOutgoing
+    };
 
 
 signals:
@@ -54,15 +60,17 @@ signals:
 
 public slots:
     void addChatTab(QXmppMessage message);
-    void updateTabTitle(int count);
+    void resetTabTitle(QString chatTitle, int count);
     void closeTab(int tabIndex);
     void closeCurrentTab();
     void addOutgoingMessage(QString toJid, QString message);
+    void startConversation(QString toJid);
 
 
 private:
     QVBoxLayout *m_mainLayout;
     QTabWidget *m_tabWidget;
+    QLabel *m_noChatsLabel;
 
     QList<ChatWidget *> m_openedChats;
 
