@@ -325,32 +325,29 @@ void ChatWidget::sendMessage()
 
 
 
-void ChatWidget::onParticipantJoined(QString nickname)
+void ChatWidget::onParticipantJoined(QString jid)
 {
-    QString nick = Helpers::nickFromRoomJid(nickname);
-    nick = Helpers::safeForHtml(nick);
+    const QString nick = Helpers::nickFromRoomJid(jid);
 
+    // FIXME: make translatable
     m_chatBrowser->append("<div style=\"color:#DD0000\">"
                           "<b>[" + QTime::currentTime().toString()
                           + "]</b> <i>+++++ "
-                          + nick
+                          + Helpers::safeForHtml(nick)
                           + " joined.</i></div>");
-
-    // TODO: Future capability to auto-greet in certain conditions
-    //m_muc->sendMessage("Hi, " + nick);
 }
 
 
 
-void ChatWidget::onParticipantLeft(QString nickname)
+void ChatWidget::onParticipantLeft(QString jid)
 {
-    QString nick = Helpers::nickFromRoomJid(nickname);
-    nick = Helpers::safeForHtml(nick);
+    const QString nick = Helpers::nickFromRoomJid(jid);
 
+    // FIXME: make translatable
     m_chatBrowser->append("<div style=\"color:#DD0000\">"
                           "<b>[" + QTime::currentTime().toString()
                           + "]</b> <i>----- "
-                          + nick
+                          + Helpers::safeForHtml(nick)
                           + " left.</i></div>");
 }
 
@@ -448,9 +445,6 @@ void ChatWidget::onRoomNameChanged(QString newName)
                             "<br />"); // ---------------------
 
     m_globalObject->addFullyJoinedRoom(m_mucJid);
-
-    qDebug() << "ChatWidget::onRoomNameChanged(), room:"
-             << m_mucJid << "\nReadable name:" << newName;
 }
 
 
