@@ -75,8 +75,8 @@ public slots:
     void sendMessage();
 
     // MUC related
-    void onParticipantJoined(QString nickname);
-    void onParticipantLeft(QString nickname);
+    void onParticipantJoined(QString jid);
+    void onParticipantLeft(QString jid);
 
     void onJoined();
     void onLeft();
