@@ -79,11 +79,13 @@ void CommandHandler::processCommand(QXmppMessage message)
                 return;
             }
 
-            // FIXME: log only if it's a recognized command?
-            m_globalObject->addToLog(tr("Command from %1 in room %2: %3")
-                                     .arg("'<b>" + fromNick.toHtmlEscaped() + "</b>'")
-                                     .arg("<b>" + bareFrom.toHtmlEscaped() + "</b>")
-                                     .arg(message.body().toHtmlEscaped()));
+            // Ignore commands if the room is configured to not allow them
+            if (!room->property("allowCommands").toBool())
+            {
+                qDebug() << "Room" << bareFrom << "doesn't allow commands:"
+                         << message.body();
+                return;
+            }
 
             commandReply = this->parseCommand(message.body(),
                                               userAccessLevel,
@@ -93,8 +95,31 @@ void CommandHandler::processCommand(QXmppMessage message)
                                                   .toBool();
             const bool hasReplyPattern = commandReply.value("haveReplyPattern")
                                                      .toBool();
-            if (!reply.isEmpty())
+            const QString deniedCommand = commandReply.value("deniedCommand")
+                                                      .toString();
+
+            if (!deniedCommand.isEmpty())
             {
+                m_globalObject->addToLog(tr("Command %1 requested by %2 in "
+                                            "room %3 without the right access "
+                                            "level.")
+                                         .arg("'<b>" + deniedCommand + "</b>'")
+                                         .arg("'<b>" + fromNick.toHtmlEscaped()
+                                              + "</b>'")
+                                         .arg("<b>" + bareFrom.toHtmlEscaped()
+                                              + "</b>"),
+                                         true, // In status bar, too
+                                         GlobalObject::LogBad);
+            }
+            else if (!reply.isEmpty())
+            {
+                m_globalObject->addToLog(tr("Command from %1 in room %2: %3")
+                                         .arg("'<b>" + fromNick.toHtmlEscaped()
+                                              + "</b>'")
+                                         .arg("<b>" + bareFrom.toHtmlEscaped()
+                                              + "</b>")
+                                         .arg(message.body().toHtmlEscaped()));
+
                 if (privateReply)
                 {
                     m_globalObject->sendPrivateMessage(message.from(), reply);
@@ -116,21 +141,36 @@ void CommandHandler::processCommand(QXmppMessage message)
     }
     else // Any other type; Error type is handled before entering this method
     {
-        m_globalObject->addToLog(tr("Command from %1: %2")
-                                 .arg("<b>" + message.from().toHtmlEscaped() + "</b>")
-                                 .arg(message.body().toHtmlEscaped()));
-
-        // TODO: handle per-user flood
-
         // Get the username part of the JID as nickname
         const QString niceNick = bareFrom.split("@").takeFirst();
 
+        // TODO: handle per-user flood
+
         commandReply = this->parseCommand(message.body(),
                                           userAccessLevel,
                                           niceNick);
         const QString reply = commandReply.value("replyString").toString();
-        if (!reply.isEmpty())
+
+        const QString deniedCommand = commandReply.value("deniedCommand")
+                                                  .toString();
+
+        if (!deniedCommand.isEmpty())
         {
+            m_globalObject->addToLog(tr("Command %1 requested by %2 without "
+                                        "the right access level.")
+                                     .arg("'<b>" + deniedCommand + "</b>'")
+                                     .arg("'<b>" + message.from().toHtmlEscaped()
+                                          + "</b>'"),
+                                     true, // In status bar, too
+                                     GlobalObject::LogBad);
+        }
+        else if (!reply.isEmpty())
+        {
+            m_globalObject->addToLog(tr("Command from %1: %2")
+                                     .arg("<b>" + message.from().toHtmlEscaped()
+                                          + "</b>")
+                                     .arg(message.body().toHtmlEscaped()));
+
             m_globalObject->sendPrivateMessage(message.from(), reply);
         }
     }
@@ -158,6 +198,7 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
     QString commandReply;
     QString outputPattern;
     bool privateReply = false; // Initialize for the hardcoded commands
+    QString deniedCommand;
 
 
     if (command == QStringLiteral("help"))
@@ -178,7 +219,7 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
         {
             const QString query = parameters.trimmed();
             QString helpMessage;
-            foreach (QVariant mapVariant, m_commandDataList)
+            foreach (const QVariant mapVariant, m_commandDataList)
             {
                 const QVariantMap map = mapVariant.toMap();
                 if (map.value("trigger").toString() == query)
@@ -210,7 +251,7 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
 
         commandReply = tr("Available commands")
                        + ":\n>    ";
-        foreach (QString trigger, availableCommands)
+        foreach (const QString trigger, availableCommands)
         {
             commandReply.append(QString("%1,   ").arg(trigger));
         }
@@ -239,24 +280,17 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
     }
     else //////////////////////////////////////////////// User-defined commands
     {
-        foreach (QVariant mapVariant, m_commandDataList)
+        foreach (const QVariant mapVariant, m_commandDataList)
         {
             const QVariantMap map = mapVariant.toMap();
             if (map.value("trigger").toString() == command)
             {
                 if (userAccess < map.value("accessLevel").toInt())
                 {
-                    // FIXME: user JID should be shown here
-                    // A previous log message shows the JID, though
-                    m_globalObject->addToLog(tr("Command %1 requested without "
-                                                "the right access level.")
-                                             .arg("'<b>" + command + "</b>'"),
-                                             true, // In status bar, too
-                                             GlobalObject::LogBad);
+                    deniedCommand = command;
 
                     qDebug() << "Command" << command
                              << "requested without privileges!";
-                    qDebug() << "-- Ignoring.";
                     break;
                 }
 
@@ -317,7 +351,7 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
                         const QStringList keywords = map.value("keywords")
                                                         .toMap().keys();
                         commandReply.append("\n>    ");
-                        foreach (QString keyword, keywords)
+                        foreach (const QString keyword, keywords)
                         {
                             commandReply.append(QString("%1,   ").arg(keyword));
                         }
@@ -338,6 +372,14 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
                         {
                             commandReply = tr("I don't have a match for %1")
                                            .arg("'" + parameters + "'");
+
+                            commandReply.append("\n>  ");
+                            const QStringList keywords = replies.keys();
+                            foreach (const QString keyword, keywords)
+                            {
+                                commandReply.append(QString("%1,  ").arg(keyword));
+                            }
+                            commandReply.remove(-3, 3); // Remove last comma
                         }
                     }
                 }
@@ -460,6 +502,7 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
     replyMap.insert("replyString",      commandReply);
     replyMap.insert("privateReply",     privateReply);
     replyMap.insert("haveReplyPattern", !outputPattern.isEmpty());
+    replyMap.insert("deniedCommand",    deniedCommand);
 
     return replyMap;
 }
@@ -475,11 +518,12 @@ void CommandHandler::setCommandData(QVariantList dataList)
 QStringList CommandHandler::getCommandList(int accessLevel)
 {
     QStringList list;
-    foreach (QVariant mapVariant, m_commandDataList)
+    foreach (const QVariant mapVariant, m_commandDataList)
     {
-        if (mapVariant.toMap().value("accessLevel").toInt() <= accessLevel)
+        const QVariantMap commandMap = mapVariant.toMap();
+        if (commandMap.value("accessLevel").toInt() <= accessLevel)
         {
-            list.append(mapVariant.toMap().value("trigger").toString());
+            list.append(commandMap.value("trigger").toString());
         }
     }
 
