@@ -28,8 +28,11 @@ CommandModule::CommandModule(CommandHandler *commandHandler,
     m_globalObject = globalObject;
     m_commandHandler = commandHandler;
 
+    m_variableParser = m_globalObject->getVariableParser();
+
+
     m_dataFile = new DataFile(m_globalObject->getDataDirectory()
-                              + "/commands.axb",
+                              + QStringLiteral("/commands.axb"),
                               this);
 
     // Left side
@@ -65,53 +68,55 @@ CommandModule::CommandModule(CommandHandler *commandHandler,
 
 
     // Right side
-    this->triggerLineEdit = new QLineEdit(this);
-    triggerLineEdit->setPlaceholderText(tr("The name, without the prefix"));
-    connect(triggerLineEdit, SIGNAL(textChanged(QString)),
-            this, SLOT(onTriggerChanged(QString)));
+    m_triggerLineEdit = new QLineEdit(this);
+    m_triggerLineEdit->setPlaceholderText(tr("The name, without the prefix "
+                                             "or any spaces",
+                                             "Referring to the command's name/trigger"));
+    connect(m_triggerLineEdit, &QLineEdit::textChanged,
+            this, &CommandModule::onTriggerChanged);
 
     m_helpLineEdit = new QLineEdit(this);
     m_helpLineEdit->setPlaceholderText(tr("Explanation shown to users with "
                                           "the %1 command")
-                                       .arg("!help"));
+                                       .arg(QStringLiteral("!help"))); // FIXME, hardcoded
 
-    this->accessLevelSpinbox = new QSpinBox(this);
-    accessLevelSpinbox->setRange(0, 100);
-    accessLevelSpinbox->setSpecialValueText(tr("Anyone can use it",
-                                               "'it' refers to a command"));
+    m_accessLevelSpinbox = new QSpinBox(this);
+    m_accessLevelSpinbox->setRange(0, 100);
+    m_accessLevelSpinbox->setSpecialValueText(tr("Anyone can use it",
+                                                 "'it' refers to a command"));
 
-    this->typeCombobox = new QComboBox(this);
-    typeCombobox->addItem(tr("Static Message"),
-                          tr("Just enter a single sentence."));
-    typeCombobox->addItem(tr("Random Sentence"),
-                          tr("Add as many sentences as you want.\n"
-                             "One of them will be selected at random as "
-                             "a reply."));
-    typeCombobox->addItem(tr("Random Line from Text File") + " (UTF-8)",
-                          tr("A random line from the chosen file will be used "
-                             "as a reply.\n"
-                             "File encoding should be UTF-8."));
-    typeCombobox->addItem(tr("Keyword-based Message"),
-                          tr("Add keywords to the list, then enter the "
-                             "corresponding definition for each keyword on "
-                             "the other side."));
-    typeCombobox->addItem(tr("Run Program"),
-                          tr("Enter a system command line to be run, with "
-                             "any needed parameters.\n"
-                             "The reply will be the console output of the "
-                             "program, unless you specify a reply pattern, "
-                             "and don't include the %output% variable "
-                             "somewhere in it.",
-                             "Don't translate %output%!")
-                          + "\n\n"
-                          + tr("If the program you launch will take a long "
-                               "time to finish (like a GUI), you need to "
-                               "select the option to launch it independently, "
-                               "but then it will not be possible to use the "
-                               "program output as the reply for the command."));
-    typeCombobox->addItem(tr("Alias for another command"),
-                          tr("Enter the original command that should be run "
-                             "when this alias is used."));
+    m_typeCombobox = new QComboBox(this);
+    m_typeCombobox->addItem(tr("Static Message"),
+                            tr("Just enter a single sentence."));
+    m_typeCombobox->addItem(tr("Random Sentence"),
+                            tr("Add as many sentences as you want.\n"
+                               "One of them will be selected at random as "
+                               "a reply."));
+    m_typeCombobox->addItem(tr("Random Line from Text File") + " (UTF-8)",
+                            tr("A random line from the chosen file will be "
+                               "used as a reply.\n"
+                               "File encoding should be UTF-8."));
+    m_typeCombobox->addItem(tr("Keyword-based Message"),
+                            tr("Add keywords to the list, then enter the "
+                               "corresponding definition for each keyword on "
+                               "the other side."));
+    m_typeCombobox->addItem(tr("Run Program"),
+                            tr("Enter a system command line to be run, with "
+                               "any needed parameters.\n"
+                               "The reply will be the console output of the "
+                               "program, unless you specify a reply pattern, "
+                               "and don't include the %output% variable "
+                               "somewhere in it.",
+                               "Don't translate %output%!")
+                            + "\n\n"
+                            + tr("If the program you launch will take a long "
+                                 "time to finish (like a GUI), you need to "
+                                 "select the option to launch it independently, "
+                                 "but then it will not be possible to use the "
+                                 "program output as the reply for the command."));
+    m_typeCombobox->addItem(tr("Alias for another command"),
+                            tr("Enter the original command that should be run "
+                               "when this alias is used."));
 
     QFont helpFont;
     helpFont.setItalic(true);
@@ -123,31 +128,37 @@ CommandModule::CommandModule(CommandHandler *commandHandler,
     m_typeExplanationLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
                                           QSizePolicy::Minimum);
 
-    connect(typeCombobox, SIGNAL(currentIndexChanged(int)),
-            this, SLOT(onTypeChanged(int)));
+    connect(m_typeCombobox, SIGNAL(currentIndexChanged(int)), // Kept old-style
+            this, SLOT(onTypeChanged(int)));                  // due to overload
 
 
-    this->staticLineEdit = new QLineEdit(this);
+    m_staticLineEdit = new QLineEdit(this);
 
-    this->randomListWidget = new StringListWidget(false, this);
+    m_randomListWidget = new StringListWidget(StringListWidget::StringsWithTags,
+                                              this);
+    m_randomListWidget->setCheckSyntaxEnabled(m_variableParser,
+                                              QStringList{"%user%", "%params%"});
 
-    this->filenameLabel = new QLabel(this);
-    QFont filenameFont = filenameLabel->font();
+    m_filenameLabel = new QLabel(this);
+    QFont filenameFont = m_filenameLabel->font();
     filenameFont.setBold(true);
-    filenameLabel->setFont(filenameFont);
-    this->filenameButton = new QPushButton(QIcon::fromTheme("document-open",
-                                                            QIcon(":/images/button-edit.png")),
-                                           tr("Select File..."),
-                                           this);
-    connect(filenameButton, SIGNAL(clicked()),
-            this, SLOT(findFile()));
-    this->filenameLayout = new QHBoxLayout();
-    filenameLayout->addWidget(filenameLabel,  1);
-    filenameLayout->addWidget(filenameButton, 0);
+    m_filenameLabel->setFont(filenameFont);
+    m_filenameButton = new QPushButton(QIcon::fromTheme("document-open",
+                                                        QIcon(":/images/button-edit.png")),
+                                       tr("Select File..."),
+                                       this);
+    connect(m_filenameButton, &QAbstractButton::clicked,
+            this, &CommandModule::findFile);
+    m_filenameLayout = new QHBoxLayout();
+    m_filenameLayout->addWidget(m_filenameLabel,  1);
+    m_filenameLayout->addWidget(m_filenameButton, 0);
 
 
-    this->keywordListWidget = new StringListWidget(true, this);
-    keywordListWidget->setLowercaseItems(true);
+    m_keywordListWidget = new StringListWidget(StringListWidget::KeysWithValues,
+                                               this);
+    m_keywordListWidget->setLowercaseItems(true);
+    m_keywordListWidget->setCheckSyntaxEnabled(m_variableParser,
+                                               QStringList{"%user%", "%params%"});
 
 
     m_programLineEdit = new QLineEdit(this);
@@ -159,12 +170,12 @@ CommandModule::CommandModule(CommandHandler *commandHandler,
     m_programLayout->addWidget(m_runDetachedCombobox);
 
 
-    this->aliasLineEdit = new QLineEdit(this);
+    m_aliasLineEdit = new QLineEdit(this);
 
 
 
-    this->outputLineEdit = new QLineEdit(this);
-    this->outputLineEdit->setPlaceholderText(tr("Set an optional reply pattern"));
+    m_outputLineEdit = new QLineEdit(this);
+    m_outputLineEdit->setPlaceholderText(tr("Set an optional reply pattern"));
 
     m_outputPatternHelpLabel = new QLabel(
       tr("With a reply pattern you can make any possible reply to a command "
@@ -193,7 +204,7 @@ CommandModule::CommandModule(CommandHandler *commandHandler,
     m_outputPatternHelpLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
                                             QSizePolicy::Minimum);
 
-    this->privateReplyCheckbox = new QCheckBox(this);
+    m_privateReplyCheckbox = new QCheckBox(this);
 
 
 
@@ -213,50 +224,55 @@ CommandModule::CommandModule(CommandHandler *commandHandler,
     m_leftLayout->addWidget(m_removeCommandButton);
 
     // These go in a sublayout to avoid spacing issues between them
-    this->typeLayout = new QVBoxLayout();
-    typeLayout->setContentsMargins(0, 0, 0, 0);
-    typeLayout->setSpacing(0);
-    typeLayout->addWidget(staticLineEdit);
-    typeLayout->addWidget(randomListWidget);
-    typeLayout->addLayout(filenameLayout);
-    typeLayout->addWidget(keywordListWidget);
-    typeLayout->addLayout(m_programLayout);
-    typeLayout->addWidget(aliasLineEdit);
+    m_typeLayout = new QVBoxLayout();
+    m_typeLayout->setContentsMargins(0, 0, 0, 0);
+    m_typeLayout->setSpacing(0);
+    m_typeLayout->addWidget(m_staticLineEdit);
+    m_typeLayout->addWidget(m_randomListWidget);
+    m_typeLayout->addLayout(m_filenameLayout);
+    m_typeLayout->addWidget(m_keywordListWidget);
+    m_typeLayout->addLayout(m_programLayout);
+    m_typeLayout->addWidget(m_aliasLineEdit);
 
 
-    this->formLayout = new QFormLayout();
-    formLayout->addRow(tr("Command"),         triggerLineEdit);
-    formLayout->addRow(tr("Help Text"),       m_helpLineEdit);
-    formLayout->addRow(tr("Access Level"),    accessLevelSpinbox);
+    m_formLayout = new QFormLayout();
+    m_formLayout->addRow(tr("Command"),         m_triggerLineEdit);
+    m_formLayout->addRow(tr("Help Text"),       m_helpLineEdit);
+    m_formLayout->addRow(tr("Access Level"),    m_accessLevelSpinbox);
 
-    formLayout->addRow(tr("Type"),            typeCombobox);
-    formLayout->addWidget(m_typeExplanationLabel);
-    formLayout->addRow(QString(), typeLayout);
+    m_formLayout->addRow(tr("Type"),            m_typeCombobox);
+    m_formLayout->addWidget(m_typeExplanationLabel);
+    m_formLayout->addRow(QString(),             m_typeLayout);
 
-    formLayout->addRow(tr("Reply Pattern"),   outputLineEdit);
-    formLayout->addWidget(m_outputPatternHelpLabel);
-    formLayout->addRow(tr("Private Reply"),   privateReplyCheckbox);
-
-
-    this->rightLayout = new QVBoxLayout();
-    rightLayout->addLayout(formLayout);
-    rightLayout->addStretch();
-    rightLayout->addWidget(m_saveCommandButton, 0, Qt::AlignRight);
+    m_formLayout->addRow(tr("Reply Pattern"),   m_outputLineEdit);
+    m_formLayout->addWidget(m_outputPatternHelpLabel);
+    m_formLayout->addRow(tr("Private Reply"),   m_privateReplyCheckbox);
 
     m_rightWidget = new QWidget(this);
-    m_rightWidget->setLayout(rightLayout);
+    m_rightWidget->setLayout(m_formLayout);
 
+    m_rightScrollArea = new QScrollArea(this);
+    m_rightScrollArea->setContentsMargins(1, 1, 1, 1);
+    m_rightScrollArea->setFrameStyle(QFrame::Box | QFrame::Raised);
+    m_rightScrollArea->setWidgetResizable(true);
+    m_rightScrollArea->setWidget(m_rightWidget);
+
+    m_rightLayout = new QVBoxLayout();
+    m_rightLayout->addWidget(m_rightScrollArea);
+    m_rightLayout->addWidget(m_saveCommandButton, 0, Qt::AlignRight);
 
     m_mainLayout = new QHBoxLayout();
     m_mainLayout->setContentsMargins(0, 0, 0, 0);
     m_mainLayout->addLayout(m_leftLayout,  1);
-    m_mainLayout->addWidget(m_rightWidget, 5);
+    m_mainLayout->addLayout(m_rightLayout, 5);
     this->setLayout(m_mainLayout);
 
 
     this->onTypeChanged(0); // Select first type to show its extra widget
     m_removeCommandButton->setDisabled(true);
     m_rightWidget->setDisabled(true);
+    m_saveCommandButton->setDisabled(true);
+
 
     this->loadCommands();
 
@@ -281,12 +297,12 @@ void CommandModule::loadCommands()
 {
     const QVariantList commandDataList = m_dataFile->loadData();
 
-    foreach (QVariant listItem, commandDataList)
+    foreach (const QVariant listItem, commandDataList)
     {
-        QVariantMap map = listItem.toMap();
+        const QVariantMap map = listItem.toMap();
         QListWidgetItem *item = new QListWidgetItem();
 
-        int commandType = map.value("type").toInt();
+        const int commandType = map.value("type").toInt();
 
         item->setText(map.value("trigger").toString());
         item->setData(Qt::UserRole,     map.value("trigger"));
@@ -344,39 +360,54 @@ bool CommandModule::validateCommand(int commandType)
 {
     QString errorMessage;
 
-    if (commandType == 0)
+    const QString commandTrigger = m_triggerLineEdit->text().trimmed();
+    const QString outputPattern = m_outputLineEdit->text().trimmed();
+
+    if (commandTrigger.contains(QStringLiteral(" "))) // FIXME, regexp
     {
-        if (this->staticLineEdit->text().trimmed().isEmpty())
+        errorMessage = tr("The command name can't contain spaces.");
+    }
+    else if (commandType == 0)
+    {
+        const QString staticReplyText = m_staticLineEdit->text().trimmed();
+        if (staticReplyText.isEmpty())
         {
             errorMessage = tr("Static reply is empty.");
-            this->staticLineEdit->setFocus();
+            m_staticLineEdit->setFocus();
+        }
+        else if (!m_variableParser->checkSyntax(staticReplyText,
+                                                QStringList{"%user%",
+                                                            "%params%"}))
+        {
+            errorMessage = m_variableParser->getLastCheckError();
+            m_staticLineEdit->setFocus();
         }
     }
     else if (commandType == 1)
     {
-        if (this->randomListWidget->getStringsFromList().length() == 0)
+        if (m_randomListWidget->getStringsFromList().length() == 0)
         {
             errorMessage = tr("There are no sentences in the list.");
-            this->randomListWidget->setFocus();
+            m_randomListWidget->setFocus();
         }
     }
     else if (commandType == 2)
     {
-        if (this->textFilename.isEmpty())
+        if (m_textFilename.isEmpty())
         {
             errorMessage = tr("There is no file selected.");
-            this->filenameButton->setFocus();
+            m_filenameButton->setFocus();
         }
     }
     else if (commandType == 3)
     {
-        if (this->keywordListWidget->getStringsFromList().length() == 0)
+        if (m_keywordListWidget->getStringsFromList().length() == 0)
         {
             errorMessage = tr("There are no keywords in the list.");
-            this->keywordListWidget->setFocus();
+            m_keywordListWidget->setFocus();
         }
 
-        // TODO -- FIXME: Check that each keyword has content
+        // TODO FIXME: Check that each keyword has content (in StringListWidget)
     }
     else if (commandType == 4)
     {
@@ -388,22 +419,34 @@ bool CommandModule::validateCommand(int commandType)
     }
     else if (commandType == 5)
     {
-        if (this->aliasLineEdit->text().trimmed().isEmpty())
+        if (m_aliasLineEdit->text().trimmed().isEmpty())
         {
             errorMessage = tr("You need to enter the command this alias "
                               "will execute.");
-            this->aliasLineEdit->setFocus();
+            m_aliasLineEdit->setFocus();
         }
-        else if (this->aliasLineEdit->text().trimmed()
-              == this->triggerLineEdit->text().trimmed())
+        else if (m_aliasLineEdit->text().trimmed() == commandTrigger)
         {
             errorMessage = tr("A command can't be an alias of itself.");
-            this->aliasLineEdit->setFocus();
+            m_aliasLineEdit->setFocus();
         }
     }
 
 
-    if (!errorMessage.isEmpty())
+    // Previous fields OK, and have some output pattern that needs checking too
+    if (errorMessage.isEmpty() && !outputPattern.isEmpty())
+    {   // FIXME: can't rely on empty errorMessage
+        if (!m_variableParser->checkSyntax(outputPattern,
+                                           QStringList{"%output%", "%user%",
+                                                       "%params%"}))
+        {
+            errorMessage = m_variableParser->getLastCheckError();
+            m_outputLineEdit->setFocus();
+        }
+    }
+
+
+    if (!errorMessage.isEmpty()) // FIXME: can't rely on that
     {
         QMessageBox::warning(this,
                              tr("Error validating fields") +  " - AkariXB",
@@ -440,13 +483,13 @@ void CommandModule::findFile()
     if (!QFile(filename).exists())
     {
         filename.clear();
-        this->filenameLabel->setText(tr("Selected file does not exist."));
+        m_filenameLabel->setText(tr("Selected file does not exist."));
     }
 
     if (!filename.isEmpty())
     {
-        this->textFilename = filename;
-        this->filenameLabel->setText(filename);
+        m_textFilename = filename;
+        m_filenameLabel->setText(filename);
     }
 }
 
@@ -465,7 +508,7 @@ void CommandModule::addCommand()
     item->setSelected(true);
 
     m_saveCommandButton->setDisabled(true); // Until something's entered
-    this->triggerLineEdit->setFocus();
+    m_triggerLineEdit->setFocus();
 }
 
 
@@ -482,6 +525,7 @@ void CommandModule::removeCommand()
     {
         m_removeCommandButton->setDisabled(true);
         m_rightWidget->setDisabled(true);
+        m_saveCommandButton->setDisabled(true);
     }
 }
 
@@ -495,40 +539,41 @@ void CommandModule::onCommandSelected(int row)
 
     QListWidgetItem *item = m_commandListWidget->item(row);
 
-    this->triggerLineEdit->setText(item->data(Qt::UserRole).toString());
+    m_triggerLineEdit->setText(item->data(Qt::UserRole).toString());
     m_helpLineEdit->setText(item->data(Qt::UserRole + 1).toString());
-    this->accessLevelSpinbox->setValue(item->data(Qt::UserRole + 2).toInt());
-    this->typeCombobox->setCurrentIndex(item->data(Qt::UserRole + 3).toInt());
+    m_accessLevelSpinbox->setValue(item->data(Qt::UserRole + 2).toInt());
+    m_typeCombobox->setCurrentIndex(item->data(Qt::UserRole + 3).toInt());
 
-    this->staticLineEdit->clear();
-    this->randomListWidget->clearList();
-    this->filenameLabel->setText("[" + tr("No file selected") + "]");
-    this->textFilename.clear();
-    this->keywordListWidget->clearList();
+    m_staticLineEdit->clear();
+    m_randomListWidget->clearList();
+    m_filenameLabel->setText("[" + tr("No file selected") + "]");
+    m_textFilename.clear();
+    m_keywordListWidget->clearList();
     m_programLineEdit->clear();
     m_runDetachedCombobox->setCurrentIndex(0);
-    this->aliasLineEdit->clear();
+    m_aliasLineEdit->clear();
 
 
-    int commandType = typeCombobox->currentIndex();
+    const int commandType = m_typeCombobox->currentIndex();
     if (commandType == 0)
     {
-        this->staticLineEdit->setText(item->data(Qt::UserRole + 4).toString());
+        m_staticLineEdit->setText(item->data(Qt::UserRole + 4).toString());
     }
     else if (commandType == 1)
     {
-        QStringList stringList = item->data(Qt::UserRole + 4).toStringList();
-        this->randomListWidget->addStringsToList(stringList);
+        const QStringList stringList = item->data(Qt::UserRole + 4)
+                                            .toStringList();
+        m_randomListWidget->addStringsToList(stringList);
     }
     else if (commandType == 2)
     {
-        this->textFilename = item->data(Qt::UserRole + 4).toString();
-        this->filenameLabel->setText(this->textFilename);
+        m_textFilename = item->data(Qt::UserRole + 4).toString();
+        m_filenameLabel->setText(m_textFilename);
     }
     else if (commandType == 3)
     {
         const QVariantMap stringMap = item->data(Qt::UserRole + 4).toMap();
-        this->keywordListWidget->addItemsToList(stringMap);
+        m_keywordListWidget->addItemsToList(stringMap);
     }
     else if (commandType == 4)
     {
@@ -540,12 +585,12 @@ void CommandModule::onCommandSelected(int row)
     }
     else if (commandType == 5)
     {
-        this->aliasLineEdit->setText(item->data(Qt::UserRole + 4).toString());
+        m_aliasLineEdit->setText(item->data(Qt::UserRole + 4).toString());
     }
 
 
-    this->outputLineEdit->setText(item->data(Qt::UserRole + 5).toString());
-    this->privateReplyCheckbox->setChecked(item->data(Qt::UserRole + 6).toBool());
+    m_outputLineEdit->setText(item->data(Qt::UserRole + 5).toString());
+    m_privateReplyCheckbox->setChecked(item->data(Qt::UserRole + 6).toBool());
 
 
     m_removeCommandButton->setEnabled(true);
@@ -556,34 +601,35 @@ void CommandModule::onCommandSelected(int row)
 void CommandModule::onTypeChanged(int commandType)
 {
     // Show the informational text for this command type
-    m_typeExplanationLabel->setText(typeCombobox->itemData(commandType).toString());
+    m_typeExplanationLabel->setText(m_typeCombobox->itemData(commandType)
+                                                   .toString());
 
-    this->staticLineEdit->hide();
-    this->randomListWidget->hide();
-    this->filenameLabel->hide();
-    this->filenameButton->hide();
-    this->keywordListWidget->hide();
+    m_staticLineEdit->hide();
+    m_randomListWidget->hide();
+    m_filenameLabel->hide();
+    m_filenameButton->hide();
+    m_keywordListWidget->hide();
     m_programLineEdit->hide();
     m_runDetachedCombobox->hide();
-    this->aliasLineEdit->hide();
+    m_aliasLineEdit->hide();
 
 
     if (commandType == 0)
     {
-        this->staticLineEdit->show();
+        m_staticLineEdit->show();
     }
     else if (commandType == 1)
     {
-        this->randomListWidget->show();
+        m_randomListWidget->show();
     }
     else if (commandType == 2)
     {
-        this->filenameLabel->show();
-        this->filenameButton->show();
+        m_filenameLabel->show();
+        m_filenameButton->show();
     }
     else if (commandType == 3)
     {
-        this->keywordListWidget->show();
+        m_keywordListWidget->show();
     }
     else if (commandType == 4)
     {
@@ -592,15 +638,15 @@ void CommandModule::onTypeChanged(int commandType)
     }
     else if (commandType == 5)
     {
-        this->aliasLineEdit->show();
+        m_aliasLineEdit->show();
     }
 }
 
 
 void CommandModule::saveCommand()
 {
-    QString newTrigger = triggerLineEdit->text().trimmed();
-    int commandType = typeCombobox->currentIndex();
+    const QString newTrigger = m_triggerLineEdit->text().trimmed();
+    const int commandType = m_typeCombobox->currentIndex();
 
     // Check for duplicates
     for (int counter = 0; counter < m_commandListWidget->count(); ++counter)
@@ -614,7 +660,7 @@ void CommandModule::saveCommand()
                                      tr("Command exists"),
                                      tr("Error: There is already a command "
                                         "in the list with this name."));
-                this->triggerLineEdit->setFocus();
+                m_triggerLineEdit->setFocus();
 
                 return;
             }
@@ -630,33 +676,33 @@ void CommandModule::saveCommand()
 
     QListWidgetItem *item = m_commandListWidget->currentItem();
 
-    triggerLineEdit->setText(newTrigger); // Show it as it will be stored
+    m_triggerLineEdit->setText(newTrigger); // Show it as it will be stored
     item->setText(newTrigger);
     item->setData(Qt::UserRole,     newTrigger);
     item->setData(Qt::UserRole + 1, m_helpLineEdit->text().trimmed());
-    item->setData(Qt::UserRole + 2, accessLevelSpinbox->value());
+    item->setData(Qt::UserRole + 2, m_accessLevelSpinbox->value());
     item->setData(Qt::UserRole + 3, commandType);
 
 
     if (commandType == 0)
     {
         item->setData(Qt::UserRole + 4,
-                      this->staticLineEdit->text().trimmed());
+                      m_staticLineEdit->text().trimmed());
     }
     else if (commandType == 1)
     {
         item->setData(Qt::UserRole + 4,
-                      this->randomListWidget->getStringsFromList());
+                      m_randomListWidget->getStringsFromList());
     }
     else if (commandType == 2)
     {
         item->setData(Qt::UserRole + 4,
-                      this->textFilename);
+                      m_textFilename);
     }
     else if (commandType == 3)
     {
         item->setData(Qt::UserRole + 4,
-                      this->keywordListWidget->getItemsFromList());
+                      m_keywordListWidget->getItemsFromList());
     }
     else if (commandType == 4)
     {
@@ -669,11 +715,11 @@ void CommandModule::saveCommand()
     else if (commandType == 5)
     {
         item->setData(Qt::UserRole + 4,
-                      this->aliasLineEdit->text().trimmed());
+                      m_aliasLineEdit->text().trimmed());
     }
 
-    item->setData(Qt::UserRole + 5, this->outputLineEdit->text().trimmed());
-    item->setData(Qt::UserRole + 6, this->privateReplyCheckbox->isChecked());
+    item->setData(Qt::UserRole + 5, m_outputLineEdit->text().trimmed());
+    item->setData(Qt::UserRole + 6, m_privateReplyCheckbox->isChecked());
 
 
     m_commandListWidget->setFocus();
