@@ -25,6 +25,7 @@
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QFormLayout>
+#include <QScrollArea>
 #include <QListWidget>
 #include <QLineEdit>
 #include <QComboBox>
@@ -42,6 +43,7 @@
 #include "commandhandler.h"
 #include "stringlistwidget.h"
 #include "datafile.h"
+#include "variableparser.h"
 
 
 class CommandModule : public QWidget
@@ -90,37 +92,38 @@ private:
     QPushButton *m_removeCommandButton;
 
 
+    QScrollArea *m_rightScrollArea;
     QWidget *m_rightWidget;
-    QVBoxLayout *rightLayout;
-    QFormLayout *formLayout;
-    QLineEdit *triggerLineEdit;
+    QVBoxLayout *m_rightLayout;
+    QFormLayout *m_formLayout;
+    QLineEdit *m_triggerLineEdit;
     QLineEdit *m_helpLineEdit;
-    QSpinBox  *accessLevelSpinbox;
-    QComboBox *typeCombobox;
+    QSpinBox  *m_accessLevelSpinbox;
+    QComboBox *m_typeCombobox;
     QLabel *m_typeExplanationLabel;
 
 
-    QVBoxLayout *typeLayout;
-    QLineEdit *staticLineEdit;
-    StringListWidget *randomListWidget;
+    QVBoxLayout *m_typeLayout;
+    QLineEdit *m_staticLineEdit;
+    StringListWidget *m_randomListWidget;
 
-    QHBoxLayout *filenameLayout;
-    QLabel *filenameLabel;
-    QString textFilename;
-    QPushButton *filenameButton;
+    QHBoxLayout *m_filenameLayout;
+    QLabel *m_filenameLabel;
+    QString m_textFilename;
+    QPushButton *m_filenameButton;
 
-    StringListWidget *keywordListWidget;
+    StringListWidget *m_keywordListWidget;
 
     QHBoxLayout *m_programLayout;
     QLineEdit *m_programLineEdit;
     QComboBox *m_runDetachedCombobox;
 
-    QLineEdit *aliasLineEdit;
+    QLineEdit *m_aliasLineEdit;
 
 
-    QLineEdit *outputLineEdit;
+    QLineEdit *m_outputLineEdit;
     QLabel *m_outputPatternHelpLabel;
-    QCheckBox *privateReplyCheckbox;
+    QCheckBox *m_privateReplyCheckbox;
 
 
     QPushButton *m_saveCommandButton;
@@ -128,6 +131,7 @@ private:
 
     DataFile *m_dataFile;
     CommandHandler *m_commandHandler;
+    VariableParser *m_variableParser;
     GlobalObject *m_globalObject;
 };
 
