@@ -35,12 +35,15 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
 
     // Tab 1: General options
-    m_adminJidListWidget = new StringListWidget(false, this);
+    m_adminJidListWidget = new StringListWidget(StringListWidget::BasicList,
+                                                this);
     m_adminJidListWidget->setDuplicatesAllowed(false);
     m_adminJidListWidget->addStringsToList(m_globalObject->getAdminJids());
 
     m_commandPrefixLineEdit = new QLineEdit(m_globalObject->getCommandPrefix(),
                                             this);
+    m_commandPrefixLineEdit->setSizePolicy(QSizePolicy::Maximum,
+                                           QSizePolicy::Maximum);
 
 
     m_keepAliveIntervalSpinbox = new QSpinBox(this);
@@ -98,10 +101,33 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     // Tab 3: System tray options
     m_hideWindowCheckbox = new QCheckBox(this);
     m_hideWindowCheckbox->setChecked(m_globalObject->getHideInTray());
+    m_customIconCheckbox = new QCheckBox(this);
+    m_customIconButton = new QPushButton(QIcon::fromTheme("user-identity",
+                                                          QIcon(":/images/no-avatar.png")),
+                                         tr("Select..."),
+                                         this);
+    m_customIconLastDir = QDir::homePath();
+    this->setCustomIconButtonImage(m_globalObject->getCustomTrayIconFilename(),
+                                   false); // Don't report errors
+    m_customIconButton->setDisabled(true);
+    connect(m_customIconButton, &QPushButton::clicked,
+            this, &ConfigDialog::pickCustomIconFile);
+
+    connect(m_customIconCheckbox, &QCheckBox::toggled,
+            m_customIconButton, &QPushButton::setEnabled);
+
+    m_customIconCheckbox->setChecked(m_globalObject->getUseCustomTrayIcon());
+
+
+    m_customIconLayout = new QHBoxLayout();
+    m_customIconLayout->addWidget(m_customIconCheckbox);
+    m_customIconLayout->addWidget(m_customIconButton);
 
     m_systrayOptionsLayout = new QFormLayout();
     m_systrayOptionsLayout->addRow(tr("Hide window on startup"),
                                    m_hideWindowCheckbox);
+    m_systrayOptionsLayout->addRow(tr("Use a custom icon"),
+                                   m_customIconLayout);
 
     m_systrayOptionsWidget = new QWidget(this);
     m_systrayOptionsWidget->setLayout(m_systrayOptionsLayout);
@@ -142,12 +168,6 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
             this, &QWidget::hide);
 
 
-    m_cancelAction = new QAction(this);
-    m_cancelAction->setShortcut(QKeySequence(Qt::Key_Escape));
-    connect(m_cancelAction, &QAction::triggered,
-            this, &QWidget::hide);
-    this->addAction(m_cancelAction);
-
 
     // Layout
     m_bottomButtonBox = new QDialogButtonBox(this);
@@ -168,6 +188,48 @@ ConfigDialog::~ConfigDialog()
     qDebug() << "ConfigDialog created";
 }
 
+
+void ConfigDialog::setCustomIconButtonImage(const QString filename,
+                                            bool reportErrors)
+{
+    if (filename.isEmpty())
+    {
+        return;
+    }
+
+    QPixmap iconPixmap = QPixmap(filename);
+    if (!iconPixmap.isNull())
+    {
+        m_customIconFilename = filename;
+        m_customIconButton->setIcon(QIcon(m_customIconFilename));
+        m_customIconButton->setToolTip("<b></b>"
+                                       + m_customIconFilename);
+    }
+    else
+    {
+        if (reportErrors)
+        {
+            QMessageBox::warning(this,
+                                 tr("Invalid icon"),
+                                 tr("The selected image is not valid."));
+        }
+        else
+        {
+            m_customIconButton->setToolTip("<b></b>"
+                                           + tr("Icon file %1 does not "
+                                                "exist").arg(filename));
+        }
+
+        qDebug() << "Invalid tray icon file selected" << filename;
+    }
+}
+
+
+//////////////////////////////////////////////////////////////////////////////
+///////////////////////////////////// SLOTS //////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
+
 void ConfigDialog::onKeepAliveChanges(int newValue)
 {
     Q_UNUSED(newValue)
@@ -181,10 +243,25 @@ void ConfigDialog::onKeepAliveChanges(int newValue)
 }
 
 
+void ConfigDialog::pickCustomIconFile()
+{
+    QString newIconFN = QFileDialog::getOpenFileName(this,
+                                                     tr("Select custom icon"),
+                                                     m_customIconLastDir,
+                                                     tr("Image files")
+                                                     + " (*.png *.jpg *.jpe "
+                                                       "*.jpeg *.gif);;"
+                                                     + tr("All files")
+                                                     + " (*)");
 
-//////////////////////////////////////////////////////////////////////////////
-///////////////////////////////////// SLOTS //////////////////////////////////
-//////////////////////////////////////////////////////////////////////////////
+    if (!newIconFN.isEmpty())
+    {
+        QFileInfo fileInfo(newIconFN);
+        m_customIconLastDir = fileInfo.path();
+
+        this->setCustomIconButtonImage(newIconFN);
+    }
+}
 
 
 
@@ -216,7 +293,13 @@ void ConfigDialog::saveSettings()
 
     settings.setValue("hideInTray",
                       m_hideWindowCheckbox->isChecked());
-    m_globalObject->syncSystraySettings(m_hideWindowCheckbox->isChecked());
+    settings.setValue("useCustomTrayIcon",
+                      m_customIconCheckbox->isChecked());
+    settings.setValue("customTrayIconFilename",
+                      m_customIconFilename);
+    m_globalObject->syncSystraySettings(m_hideWindowCheckbox->isChecked(),
+                                        m_customIconCheckbox->isChecked(),
+                                        m_customIconFilename);
 
 
     settings.endGroup();
@@ -224,5 +307,29 @@ void ConfigDialog::saveSettings()
     m_globalObject->addToLog(tr("Program configuration saved."),
                              true,
                              GlobalObject::LogGood);
+
+    emit settingsSaved();
     this->hide();
 }
+
+
+//////////////////////////////////////////////////////////////////////////////
+/////////////////////////////////// PROTECTED ////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
+
+/*
+ * Handle closing dialog via ESC.
+ * Using keyPressEvent() instead of a QAction with a shortcut, to prevent
+ * shortcut conflicts with StringListWidget's own ESC shortcut to clear
+ * the search field.
+ *
+ */
+void ConfigDialog::keyPressEvent(QKeyEvent *event)
+{
+    if (event->key() == Qt::Key_Escape)
+    {
+        event->accept();
+        this->hide();
+    }
+}
