@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ ConnectionDialog::ConnectionDialog(QString jid, QString password,
     this->setWindowIcon(QIcon::fromTheme("network-connect",
                                          QIcon(":/images/button-online.png")));
     this->setWindowFlags(Qt::Dialog);
-    this->setWindowModality(Qt::WindowModal);
+    this->setWindowModality(Qt::ApplicationModal); // Works better in some environments
     this->setMinimumSize(560, 240);
 
 
@@ -146,3 +146,27 @@ void ConnectionDialog::startConnection()
 
     this->hide();
 }
+
+
+//////////////////////////////////////////////////////////////////////////////
+/////////////////////////////////// PROTECTED ////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
+
+/*
+ * If any of the two main fields is still empty, focus it
+ *
+ */
+void ConnectionDialog::showEvent(QShowEvent *event)
+{
+    if (m_jidLineEdit->text().trimmed().isEmpty())
+    {
+        m_jidLineEdit->setFocus();
+    }
+    else if (m_passwordLineEdit->text().trimmed().isEmpty())
+    {
+        m_passwordLineEdit->setFocus();
+    }
+
+    event->accept();
+}
