@@ -153,7 +153,7 @@ bool ContactsModule::isUserOnline(QString bareJid)
     QMap<QString, QXmppPresence> presences = m_rosterManager
                                              ->getAllPresencesForBareJid(bareJid);
 
-    foreach (QString resource, presences.keys())
+    foreach (const QString resource, presences.keys())
     {
         if (m_rosterManager->getPresence(bareJid, resource).type() == QXmppPresence::Available)
         {
@@ -231,7 +231,7 @@ void ContactsModule::onRosterReceived()
 
     const QStringList rosterJids = m_rosterManager->getRosterBareJids();
 
-    foreach (QString jid, rosterJids)
+    foreach (const QString jid, rosterJids)
     {
         m_rosterListWidget->addItem(this->createContactItem(jid));
     }
