@@ -43,17 +43,34 @@ GeneralModule::GeneralModule(GlobalObject *globalObject,
     m_infoLabel->setAlignment(Qt::AlignCenter);
 
 
+    m_serverVersionLabel = new QLabel(this);
+    m_serverVersionLabel->setTextFormat(Qt::PlainText);
+    m_serverVersionLabel->setAlignment(Qt::AlignCenter);
+
+
     infoFont.setPointSize(infoFont.pointSize() - 2);
 
+
+    m_uptimeLabel = new QLabel(QStringLiteral("--"), this);
+    m_uptimeLabel->setFont(infoFont);
+    m_uptimeLabel->setWordWrap(true);
+    m_uptimeLabel->setTextFormat(Qt::PlainText);
+    m_uptimeLabel->setContentsMargins(4, 4, 4, 4);
+    m_uptimeLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
+                                 QSizePolicy::Minimum);
+
+
     m_activityLabel = new QLabel(QStringLiteral("--"), this);
     m_activityLabel->setFont(infoFont);
     m_activityLabel->setWordWrap(true);
+    m_activityLabel->setTextFormat(Qt::RichText);
     m_activityLabel->setContentsMargins(4, 4, 4, 4);
     m_activityLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
                                    QSizePolicy::Minimum);
     connect(m_globalObject, &GlobalObject::activityChanged,
             m_activityLabel, &QLabel::setText);
 
+
     m_statusMessageLabel = new QLabel(QStringLiteral("--"), this);
     m_statusMessageLabel->setFont(infoFont);
     m_statusMessageLabel->setWordWrap(true);
@@ -64,6 +81,14 @@ GeneralModule::GeneralModule(GlobalObject *globalObject,
             this, &GeneralModule::onStatusChanged);
 
 
+    m_roomsInfoLabel = new QLabel(QStringLiteral("--"), this);
+    m_roomsInfoLabel->setFont(infoFont);
+    m_roomsInfoLabel->setWordWrap(true);
+    m_roomsInfoLabel->setContentsMargins(4, 4, 4, 4);
+    m_roomsInfoLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
+                                    QSizePolicy::Minimum);
+    connect(m_globalObject, &GlobalObject::fullyJoinedRoomsChanged,
+            this, &GeneralModule::onFullyJoinedRoomsChanged);
 
 
     m_tmpPresenceBrowser = new QTextBrowser(this);
@@ -86,20 +111,29 @@ GeneralModule::GeneralModule(GlobalObject *globalObject,
             this, &GeneralModule::disconnectionRequested);
 
 
+    m_uptimeTimer = new QTimer(this);
+    m_uptimeTimer->setInterval(60000);
+    connect(m_uptimeTimer, &QTimer::timeout,
+            this, &GeneralModule::onUptimeTimerTick);
+
+
     // Layout
     m_formLayout = new QFormLayout();
+    m_formLayout->addRow(tr("Uptime:"),           m_uptimeLabel);
     m_formLayout->addRow(tr("Current Activity:"), m_activityLabel);
     m_formLayout->addRow(tr("Status Message:"),   m_statusMessageLabel);
+    m_formLayout->addRow(tr("Rooms:"),            m_roomsInfoLabel);
 
 
     m_mainLayout = new QVBoxLayout();
     m_mainLayout->setContentsMargins(0, 0, 0, 0);
     m_mainLayout->addStretch(1);
-    m_mainLayout->addWidget(m_infoLabel,          1);
+    m_mainLayout->addWidget(m_infoLabel,          2);
+    m_mainLayout->addWidget(m_serverVersionLabel, 1);
     m_mainLayout->addStretch(1);
-    m_mainLayout->addLayout(m_formLayout,         1);
+    m_mainLayout->addLayout(m_formLayout,         2);
     m_mainLayout->addStretch(1);
-    m_mainLayout->addWidget(m_tmpPresenceBrowser, 0);
+    m_mainLayout->addWidget(m_tmpPresenceBrowser, 1);
     m_mainLayout->addWidget(m_connectButton,      0, Qt::AlignRight);
     m_mainLayout->addWidget(m_disconnectButton,   0, Qt::AlignRight);
     this->setLayout(m_mainLayout);
@@ -118,10 +152,16 @@ void GeneralModule::setInfoMessage(QString message)
     m_infoLabel->setText(message);
 }
 
+void GeneralModule::setServerInfo(QString message)
+{
+    m_serverVersionLabel->setText(message);
+}
+
 
 void GeneralModule::setConnecting(bool state)
 {
     m_connectButton->setDisabled(state);
+    m_uptimeLabel->setText(QStringLiteral("..."));
 }
 
 
@@ -161,12 +201,28 @@ void GeneralModule::addPresence(QXmppPresence presence)
         // FIXME, statusText could include "%3" or something and mess this up
     }
 
+    QString presenceType;
+    switch (presence.type())
+    {
+    case QXmppPresence::Error:
+        presenceType = "Error";
+        break;
+    case QXmppPresence::Available:
+        presenceType = "Available";
+        break;
+    case QXmppPresence::Unavailable:
+        presenceType = "Unavailable";
+        break;
+
+    default:
+        presenceType = QString("%1, subscription-related").arg(presence.type());
+    }
+
     const QString presenceString = QString("%1 is %2 [Priority: %3, Type: %4]")
                                    .arg(presence.from())
                                    .arg(availableType)
                                    .arg(presence.priority())
-                                   .arg(presence.type());
-
+                                   .arg(presenceType);
 
     m_tmpPresenceBrowser->append(presenceString);
 }
@@ -182,6 +238,12 @@ void GeneralModule::onConnected()
     m_connectButton->hide();
     m_connectButton->setEnabled(true);
     m_disconnectButton->show();
+
+    m_uptimeLabel->setText(QStringLiteral("00:00"));
+    m_upMinutes = 0;
+    m_upHours = 0;
+    m_upDays = 0;
+    m_uptimeTimer->start();
 }
 
 
@@ -190,6 +252,34 @@ void GeneralModule::onDisconnected()
     m_connectButton->setEnabled(true);
     m_connectButton->show();
     m_disconnectButton->hide();
+
+    m_serverVersionLabel->clear();
+    m_uptimeTimer->stop();
+}
+
+
+void GeneralModule::onUptimeTimerTick()
+{
+    ++m_upMinutes;
+    if (m_upMinutes >= 60)
+    {
+        m_upMinutes = 0;
+        ++m_upHours;
+        if (m_upHours >= 24)
+        {
+            m_upHours = 0;
+            ++m_upDays;
+        }
+    }
+
+    QString uptime = QString("%1:%2").arg(m_upHours,   2, 10, QChar('0'))
+                                     .arg(m_upMinutes, 2, 10, QChar('0'));
+    if (m_upDays > 0)
+    {
+        uptime.prepend(QString("%1d, ").arg(m_upDays));
+    }
+
+    m_uptimeLabel->setText(uptime);
 }
 
 
@@ -199,3 +289,13 @@ void GeneralModule::onStatusChanged(QXmppPresence presence)
     // FIXME: show status type icon
 }
 
+
+void GeneralModule::onFullyJoinedRoomsChanged(int count)
+{
+    m_roomsInfoLabel->setText(tr("%1 joined, out of %2 configured",
+                                 "Number of rooms joined and configured")
+                              .arg(count)
+                              .arg(m_globalObject->getConfiguredRoomsList()
+                                                  .size()));
+}
+
