@@ -27,6 +27,7 @@
 #include <QLabel>
 #include <QPushButton>
 #include <QTextBrowser>
+#include <QTimer>
 
 #include <QDebug>
 
@@ -35,6 +36,7 @@
 #include <QXmppPresence.h>
 
 #include "globalobject.h"
+#include "helpers.h"
 
 class GeneralModule : public QWidget
 {
@@ -46,6 +48,7 @@ public:
     ~GeneralModule();
 
     void setInfoMessage(QString message);
+    void setServerInfo(QString message);
     void setConnecting(bool state);
     void addPresence(QXmppPresence presence);
 
@@ -59,7 +62,10 @@ public slots:
     void onConnected();
     void onDisconnected();
 
+    void onUptimeTimerTick();
+
     void onStatusChanged(QXmppPresence presence);
+    void onFullyJoinedRoomsChanged(int count);
 
 
 private:
@@ -67,15 +73,23 @@ private:
     QFormLayout *m_formLayout;
 
     QLabel *m_infoLabel;
+    QLabel *m_serverVersionLabel;
 
+    QLabel *m_uptimeLabel;
     QLabel *m_activityLabel;
     QLabel *m_statusMessageLabel;
+    QLabel *m_roomsInfoLabel;
 
     QTextBrowser *m_tmpPresenceBrowser;
 
     QPushButton *m_connectButton;
     QPushButton *m_disconnectButton;
 
+    QTimer *m_uptimeTimer;
+    int m_upMinutes;
+    int m_upHours;
+    int m_upDays;
+
     QXmppClient *m_xmppClient;
     GlobalObject *m_globalObject;
 };
