@@ -26,6 +26,13 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
     m_userConnected = false;
     m_connectionStartTime = QDateTime();
 
+
+    // Identity and activity-related
+    m_availability = 99;
+    m_minReactionTime = 1;
+    m_maxReactionTime = 10;
+
+
     // Load settings
     QSettings settings;
     settings.beginGroup("Configuration");
@@ -46,7 +53,11 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
 
 
     this->syncSystraySettings(settings.value("hideInTray",
-                                             false).toBool());
+                                             false).toBool(),
+                              settings.value("useCustomTrayIcon",
+                                             false).toBool(),
+                              settings.value("customTrayIconFilename")
+                                      .toString());
 
 
 
@@ -112,9 +123,12 @@ bool GlobalObject::getNotifyDisconnection()
 }
 
 
-void GlobalObject::syncSystraySettings(bool hideInTray)
+void GlobalObject::syncSystraySettings(bool hideInTray, bool useCustomIcon,
+                                       QString iconFilename)
 {
     m_hideInSystemTray = hideInTray;
+    m_useCustomTrayIcon = useCustomIcon;
+    m_customTrayIconFilename = iconFilename;
 }
 
 bool GlobalObject::getHideInTray()
@@ -122,7 +136,18 @@ bool GlobalObject::getHideInTray()
     return m_hideInSystemTray;
 }
 
+bool GlobalObject::getUseCustomTrayIcon()
+{
+    return m_useCustomTrayIcon;
+}
 
+QString GlobalObject::getCustomTrayIconFilename()
+{
+    return m_customTrayIconFilename;
+}
+
+
+/////
 
 
 void GlobalObject::setXmppClient(QXmppClient *client)
@@ -158,6 +183,17 @@ VariableParser *GlobalObject::getVariableParser()
 }
 
 
+void GlobalObject::setSpeechDataStore(SpeechDataStore *speechDataStore)
+{
+    m_speechDataStore = speechDataStore;
+}
+
+SpeechDataStore *GlobalObject::getSpeechDataStore()
+{
+    return m_speechDataStore;
+}
+
+
 
 void GlobalObject::setDataDirectory(QString path)
 {
@@ -241,16 +277,14 @@ void GlobalObject::addFullyJoinedRoom(QString roomJid)
         m_fullyJoinedRooms.append(roomJid);
     }
 
-    qDebug() << "addFullyJoinedRoom()" << roomJid;
-    qDebug() << "Current list:" << m_fullyJoinedRooms;
+    emit fullyJoinedRoomsChanged(m_fullyJoinedRooms.size());
 }
 
 void GlobalObject::removeFullyJoinedRoom(QString roomJid)
 {
     m_fullyJoinedRooms.removeAll(roomJid);
 
-    qDebug() << "removeFullyJoinedRoom()" << roomJid;
-    qDebug() << "Current list:" << m_fullyJoinedRooms;
+    emit fullyJoinedRoomsChanged(m_fullyJoinedRooms.size());
 }
 
 QStringList GlobalObject::getFullyJoinedRooms()
@@ -270,6 +304,10 @@ bool GlobalObject::isRoomFullyJoined(QString roomJid)
 void GlobalObject::setConfiguredRoomsList(QStringList roomList)
 {
     m_configuredRooms = roomList;
+
+    // Fully joined didn't change, but notify GeneralModule anyway,
+    // to update number of configured rooms
+    emit fullyJoinedRoomsChanged(m_fullyJoinedRooms.size());
 }
 
 QStringList GlobalObject::getConfiguredRoomsList()
@@ -310,15 +348,41 @@ QString GlobalObject::getOwnNickname()
 }
 
 
+void GlobalObject::setAvailability(int availability)
+{
+    m_availability = availability;
+}
+
+int GlobalObject::getAvailability()
+{
+    return m_availability;
+}
+
+
+void GlobalObject::setReactionTime(int minReactionTime, int maxReactionTime)
+{
+    m_minReactionTime = minReactionTime;
+    m_maxReactionTime = maxReactionTime;
+}
+
+int GlobalObject::getReactionTime()
+{
+    return Helpers::randomBetween(m_minReactionTime, m_maxReactionTime);
+}
+
+
 void GlobalObject::notifyActivityChange(QString name, QString timeRange)
 {
     QString text = name;
     if (!timeRange.isEmpty())
     {
-        text.append(QString::fromUtf8("   \342\217\260 ") // Alarm clock symbol
+        text.append(QString::fromUtf8(" &nbsp; &nbsp; \342\217\260 ") // Alarm clock symbol
                     + timeRange);
     }
 
+    // TMP: show availability -- FIXME
+    text.append(QString(" &nbsp; &nbsp; [%1%]").arg(m_availability));
+
     emit activityChanged(text);
 }
 
