@@ -31,7 +31,10 @@
 #include <QXmppClient.h>
 #include <QXmppMucManager.h>
 
+
 #include "variableparser.h"
+#include "helpers.h"
+#include "speechdatastore.h"
 
 
 class GlobalObject : public QObject
@@ -58,8 +61,11 @@ public:
     bool getNotifyDisconnection();
 
     // Systray settings
-    void syncSystraySettings(bool hideInTray);
+    void syncSystraySettings(bool hideInTray, bool useCustomIcon,
+                             QString iconFilename);
     bool getHideInTray();
+    bool getUseCustomTrayIcon();
+    QString getCustomTrayIconFilename();
 
 
     //////////
@@ -74,6 +80,9 @@ public:
     void setVariableParser(VariableParser *varParser);
     VariableParser *getVariableParser();
 
+    void setSpeechDataStore(SpeechDataStore *speechDataStore);
+    SpeechDataStore *getSpeechDataStore();
+
     void setDataDirectory(QString path);
     QString getDataDirectory();
 
@@ -105,12 +114,20 @@ public:
 
     QXmppMucRoom *roomFromJid(QString roomJid);
 
+
+    // Activity-related
     void setOwnNickname(QString newNick);
     QString getOwnNickname();
 
+    void setAvailability(int availability);
+    int getAvailability();
+    void setReactionTime(int minReactionTime, int maxReactionTime);
+    int getReactionTime();
+
 
     void notifyActivityChange(QString name, QString timeRange);
     void notifyStatusChange(QXmppPresence presence);
+    ///
 
 
     void sendMessageToJid(QString jid, QString message);
@@ -132,6 +149,7 @@ signals:
 
     void activityChanged(QString activityInfo);
     void statusChanged(QXmppPresence presence);
+    void fullyJoinedRoomsChanged(int count);
 
     void privateMessageSent(QString jid, QString message);
     void conversationTabRequested(QString jid);
@@ -145,6 +163,7 @@ private:
     QXmppMucManager *m_xmppMucManager;
 
     VariableParser *m_variableParser;
+    SpeechDataStore *m_speechDataStore;
 
 
     QString m_dataDirectory;
@@ -156,8 +175,12 @@ private:
     QStringList m_fullyJoinedRooms;
     QStringList m_configuredRooms;
 
+    // Identity and activity-related
     QString m_ownNickname;
 
+    int m_availability;
+    int m_minReactionTime;
+    int m_maxReactionTime;
 
 
     // General options
@@ -174,6 +197,8 @@ private:
 
     // Systray options
     bool m_hideInSystemTray;
+    bool m_useCustomTrayIcon;
+    QString m_customTrayIconFilename;
 
 };
 
