@@ -24,6 +24,20 @@
 LogModule::LogModule(QWidget *parent) : QTextBrowser(parent)
 {
     this->setReadOnly(true);
+
+    // See if we can use the nice "cross mark" symbol, or a more common fallback
+    QFontMetrics fontMetrics(this->font());
+    if (fontMetrics.inFont(QChar(0x274C)))
+    {
+        // CROSS MARK
+        m_crossSymbolString = QString::fromUtf8("\342\235\214 ");
+    }
+    else
+    {
+        // HEAVY BALLOT X as fallback (or regular BALLOT X)
+        m_crossSymbolString = QString::fromUtf8("\342\234\230 ");
+    }
+
     this->addToLog(tr("AkariXB v%1 started.",
                       "%1 = Version number").arg(qApp->applicationVersion()),
                    0); // 0=LogNormal, FIXME
@@ -55,11 +69,11 @@ void LogModule::addToLog(QString message, int messageType)
 
     if (messageType == 1)       // GlobalObject::LogGood
     {
-        logLine.append(QString::fromUtf8("\342\234\224 ")); // Check mark
+        logLine.append(QString::fromUtf8("\342\234\224 ")); // Heavy check mark
     }
     else if (messageType == 2)  // GlobalObject::LogBad
     {
-        logLine.append(QString::fromUtf8("\342\235\214 ")); // Cross
+        logLine.append(m_crossSymbolString);                // Cross mark
     }
 
     logLine.append(message);
