@@ -24,6 +24,8 @@
 #include <QTextBrowser>
 #include <QTime>
 #include <QApplication>
+#include <QFontMetrics>
+#include <QChar>
 
 #include <QDebug>
 
@@ -43,7 +45,7 @@ public slots:
     void addToLog(QString message, int messageType);
 
 private:
-
+    QString m_crossSymbolString;
 
 };
 
