@@ -45,9 +45,11 @@ int main(int argc, char *argv[])
 {
     QApplication akariApp(argc, argv);
     akariApp.setApplicationName(QStringLiteral("AkariXB"));
-    akariApp.setApplicationVersion(QStringLiteral("0.7"));
+    akariApp.setApplicationVersion(QStringLiteral("0.8"));
     akariApp.setOrganizationName(QStringLiteral("JanCoding"));
     akariApp.setOrganizationDomain(QStringLiteral("jancoding.wordpress.com"));
+    // This is mainly needed for window managers under Wayland
+    akariApp.setDesktopFileName(QStringLiteral("org.nongnu.akarixb.desktop"));
 
     std::cout << QString("AkariXB v%1 - JanKusanagi 2015-2019\n"
                          "https://jancoding.wordpress.com/akarixb\n\n")
@@ -89,7 +91,7 @@ int main(int argc, char *argv[])
 
     if (!cmdLine.isEmpty())
     {
-        foreach (QString argument, cmdLine)
+        foreach (const QString argument, cmdLine)
         {
             // Help
             if (argument.startsWith("--help", Qt::CaseInsensitive)
