@@ -47,16 +47,20 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     setupXmppClient();
 
-    // It's important to initialize this before creating the handlers, which use it
+    // It's important to initialize these before creating the handlers, which use them
     m_variableParser = new VariableParser(this);
     m_globalObject->setVariableParser(m_variableParser);
 
+    m_speechDataStore = new SpeechDataStore(this);
+    m_globalObject->setSpeechDataStore(m_speechDataStore);
+
+
     m_messageHandler = new MessageHandler(m_globalObject, this);
     m_commandHandler = new CommandHandler(m_globalObject, this);
     m_activityHandler = new ActivityHandler(m_globalObject, this);
 
 
-    // Page 9, runtime log, needed before others for early logging
+    // Page 10, runtime log, needed before others for early logging
     m_logModule = new LogModule(this);
     m_logModule->addToLog(QString("Qt v%1 (%2), QXMPP v%3, %4.")
                           .arg(qVersion(),
@@ -77,6 +81,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     createDataDir();
 
     m_configDialog = new ConfigDialog(m_globalObject, this);
+    connect(m_configDialog, &ConfigDialog::settingsSaved,
+            this, &MainWindow::setTitleAndTrayInfo); // Kinda TMP...
 
 
     // Page 1, general
@@ -98,15 +104,18 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
                                         m_globalObject,
                                         this);
 
-    // Page 6, conversations
+    // Page 6, room speak: greetings, casual sentences, reaction sentences
+    m_roomSpeakModule = new RoomSpeakModule(m_globalObject, this);
+
+    // Page 7, conversations
     m_conversationModule = new ConversationModule(this);
 
-    // Page 7, activities
+    // Page 8, activities
     m_activityModule = new ActivityModule(m_activityHandler,
                                           m_globalObject,
                                           this);
 
-    // Page 8, identity
+    // Page 9, identity
     m_identityModule = new IdentityModule(m_globalObject, this);
 
 
@@ -138,17 +147,20 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     m_categoriesList->addItem(tr("Commands"));
     m_categoriesList->item(4)->setIcon(QIcon::fromTheme("system-run",
                                                         QIcon(":/images/section-commands.png")));
-    m_categoriesList->addItem(tr("Conversation"));
+    m_categoriesList->addItem(tr("Room Speech"));
     m_categoriesList->item(5)->setIcon(QIcon::fromTheme("view-conversation-balloon",
                                                         QIcon(":/images/section-conv.png")));
+    m_categoriesList->addItem(tr("Conversation"));
+    m_categoriesList->item(6)->setIcon(QIcon::fromTheme("view-conversation-balloon",
+                                                        QIcon(":/images/section-conv.png")));
     m_categoriesList->addItem(tr("Activities"));
-    m_categoriesList->item(6)->setIcon(QIcon::fromTheme("view-categories",
+    m_categoriesList->item(7)->setIcon(QIcon::fromTheme("view-categories",
                                                         QIcon(":/images/section-general.png")));
     m_categoriesList->addItem(tr("Identity"));
-    m_categoriesList->item(7)->setIcon(QIcon::fromTheme("user-identity",
+    m_categoriesList->item(8)->setIcon(QIcon::fromTheme("user-identity",
                                                         QIcon(":/images/no-avatar.png")));
     m_categoriesList->addItem(tr("Log"));
-    m_categoriesList->item(8)->setIcon(QIcon::fromTheme("text-x-log",
+    m_categoriesList->item(9)->setIcon(QIcon::fromTheme("text-x-log",
                                                         QIcon(":/images/section-log.png")));
 
     // Pages on right side
@@ -158,6 +170,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     m_stackedWidget->addWidget(m_chatModule);
     m_stackedWidget->addWidget(m_contactsModule);
     m_stackedWidget->addWidget(m_commandModule);
+    m_stackedWidget->addWidget(m_roomSpeakModule);
     m_stackedWidget->addWidget(m_conversationModule);
     m_stackedWidget->addWidget(m_activityModule);
     m_stackedWidget->addWidget(m_identityModule);
@@ -199,15 +212,14 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     // Help widget; Syntax help, command parameters, etc.
     m_helpWidget = new HelpWidget(nullptr); // Created without a parent, so it
                                             // can be a truly independent window
-    // NOTE: using nullptr in older compilers requires -std=c++0x, handled via .pro file
 
 
     createMenus();
     createTrayIcon();
 
 
+    // Selecting the first category will also end up calling setTitleAndTrayInfo()
     m_categoriesList->setCurrentRow(0);
-    this->setTitleAndTrayInfo();
 
     /*
      * If initial connection hangs for some reason, break it and retry after
@@ -358,9 +370,15 @@ void MainWindow::createMenus()
     this->menuBar()->addMenu(m_helpMenu);
 
 
-    /// Context menu for the tray icon
+    // Context menu for the tray icon
     m_trayTitleAction = new QAction(QStringLiteral("AkariXB"), this);
-    m_trayTitleAction->setSeparator(true);
+    /* Separator actions with names don't work in some environments:
+     *
+     *  m_trayTitleAction->setSeparator(true);
+     *
+     * so just use a regular disabled action as 'title' of the menu instead
+     */
+    m_trayTitleAction->setDisabled(true);
 
     m_trayShowWindowAction = new QAction(QIcon(":/icon/64x64/akarixb.png"),
                                          QStringLiteral("*show-hide-window*"),
@@ -369,13 +387,16 @@ void MainWindow::createMenus()
             this, &MainWindow::toggleMainWindow);
 
 
-    m_systrayMenu = new QMenu(QStringLiteral("*systray-menu*"), this);
+    m_systrayMenu = new QMenu(QStringLiteral("*akarixb-systray-menu*"), this);
     m_systrayMenu->setSeparatorsCollapsible(false);
-    m_systrayMenu->addAction(m_trayTitleAction); // Not shown under Plasma 5...
+    m_systrayMenu->addAction(m_trayTitleAction);
+    m_systrayMenu->addSeparator();
     m_systrayMenu->addAction(m_trayShowWindowAction);
     m_systrayMenu->addAction(m_sessionConnectAction);
     m_systrayMenu->addAction(m_sessionDisconnectAction);
     m_systrayMenu->addSeparator();
+    m_systrayMenu->addAction(m_settingsConfigAction);
+    m_systrayMenu->addSeparator();
     m_systrayMenu->addAction(m_helpGeneralHelpAction);
     m_systrayMenu->addAction(m_helpAboutAction);
     m_systrayMenu->addSeparator();
@@ -466,10 +487,10 @@ void MainWindow::createDataDir()
                                  .arg(dataDirectory));
     }
 
-    if (!dataDir.exists(dataDirectory + "/logs"))
+    if (!dataDir.exists(dataDirectory + QStringLiteral("/logs")))
     {
         qDebug() << "Creating logs directory";
-        if (dataDir.mkpath(dataDirectory + "/logs"))
+        if (dataDir.mkpath(dataDirectory + QStringLiteral("/logs")))
         {
             qDebug() << "Logs directory created";
         }
@@ -485,7 +506,7 @@ void MainWindow::createDataDir()
 void MainWindow::setupXmppClient()
 {
     m_xmppClient = new QXmppClient(this);
-    m_xmppClient->versionManager().setClientName("AkariXB");
+    m_xmppClient->versionManager().setClientName(QStringLiteral("AkariXB"));
     m_xmppClient->versionManager().setClientOs("Akari-GNU-OS"); // tmp FIXME xD
     m_disconnectedManually = false;
 
@@ -504,12 +525,20 @@ void MainWindow::setupXmppClient()
     connect(m_xmppClient, &QXmppClient::error,
             this, &MainWindow::onNetworkError);
 
+    connect(&m_xmppClient->versionManager(), &QXmppVersionManager::versionReceived,
+            this, &MainWindow::processVersionIq);
+
     m_mucManager = new QXmppMucManager();
     m_xmppClient->addExtension(m_mucManager);
 
     m_receiptManager = new QXmppMessageReceiptManager();
     m_xmppClient->addExtension(m_receiptManager);
 
+    m_discoveryManager = new QXmppDiscoveryManager();
+    m_discoveryManager->setClientName(QStringLiteral("AkariXB ")
+                                      + qApp->applicationVersion());
+    m_discoveryManager->setClientCapabilitiesNode("http://akarixb.nongnu.org");
+    m_xmppClient->addExtension(m_discoveryManager);
 
     m_globalObject->setXmppClient(m_xmppClient);
     m_globalObject->setMucManager(m_mucManager);
@@ -701,6 +730,14 @@ void MainWindow::onConnected()
     m_globalObject->setConnected(true);
     this->setTitleAndTrayInfo();
     this->setStatusIconOnline(QXmppPresence::Online, true);
+
+    // Request server version information
+    const QStringList jidParts = m_userJid.split("@");
+    if (!jidParts.isEmpty())
+    {
+        m_userServer = jidParts.last();
+        m_xmppClient->versionManager().requestVersion(m_userServer);
+    }
 }
 
 
@@ -908,13 +945,39 @@ void MainWindow::processIq(QXmppIq iq)
     qDebug() << QTime::currentTime().toString() << "IQ" << iq.id()
              << iq.from() << ">" << iq.to() << "Type(EGSR):" << iq.type();
 
-    foreach (QXmppElement iqExt, iq.extensions())
+    foreach (const QXmppElement iqExt, iq.extensions())
     {
         qDebug() << iqExt.tagName();
     }
 }
 
 
+void MainWindow::processVersionIq(QXmppVersionIq versionIq)
+{
+    QString versionString = QString("%1 %2").arg(versionIq.name())
+                                            .arg(versionIq.version());
+    QString osString = versionIq.os();
+    if (!osString.isEmpty())
+    {
+        versionString.append(QString(" (%1)").arg(osString));
+    }
+
+    const QString message = tr("Received version information from %1:")
+                            .arg("<b>" + versionIq.from() + "</b>")
+                            + " " + versionString;;
+
+    m_globalObject->addToLog(message,
+                             true,
+                             GlobalObject::LogGood);
+
+    // Info is about our server, display it in the General section
+    if (versionIq.from() == m_userServer)
+    {
+        m_generalModule->setServerInfo(versionString);
+    }
+}
+
+
 
 void MainWindow::onNetworkError(QXmppClient::Error error)
 {
@@ -1085,13 +1148,29 @@ void MainWindow::setTitleAndTrayInfo()
     // Tray icon tooltip
     if (m_trayIconAvailable)
     {
-        if (m_globalObject->connectedToServer())
+        // FIXME -- It's overkill to do all this if only the selected section changed
+        QIcon newIcon;
+        if (m_globalObject->getUseCustomTrayIcon())
         {
-            m_systrayIcon->setIcon(QIcon(":/icon/64x64/akarixb.png"));
+            newIcon = QIcon(m_globalObject->getCustomTrayIconFilename());
+            if (newIcon.pixmap(QSize(64, 64)).isNull())
+            {
+                newIcon = QIcon(":/icon/64x64/akarixb.png");
+            }
         }
         else
         {
-            m_systrayIcon->setIcon(QIcon(":/icon/64x64/akarixb-offline.png"));
+            newIcon = QIcon(":/icon/64x64/akarixb.png");
+        }
+
+        if (m_globalObject->connectedToServer())
+        {
+            m_systrayIcon->setIcon(newIcon);
+        }
+        else
+        {
+            m_systrayIcon->setIcon(newIcon.pixmap(QSize(64, 64),
+                                                  QIcon::Disabled));
         }
 
         const QString idToShow = m_userJid.isEmpty()
