@@ -48,7 +48,9 @@
 #include <QXmppMessage.h>
 #include <QXmppMucManager.h>
 #include <QXmppVersionManager.h>
+#include <QXmppVersionIq.h>
 #include <QXmppMessageReceiptManager.h>
+#include <QXmppDiscoveryManager.h>
 
 #include <iostream>
 
@@ -63,6 +65,7 @@
 #include "chatmodule.h"
 #include "contactsmodule.h"
 #include "commandmodule.h"
+#include "roomspeakmodule.h"
 #include "conversationmodule.h"
 #include "activitymodule.h"
 #include "identitymodule.h"
@@ -72,6 +75,7 @@
 #include "commandhandler.h"
 #include "activityhandler.h"
 #include "variableparser.h"
+#include "speechdatastore.h"
 #include "helpers.h"
 
 
@@ -113,6 +117,7 @@ public slots:
     void processMessage(QXmppMessage message);
     void processPresence(QXmppPresence presence);
     void processIq(QXmppIq iq);
+    void processVersionIq(QXmppVersionIq versionIq);
 
     void onNetworkError(QXmppClient::Error error);
 
@@ -186,6 +191,7 @@ private:
     ChatModule         *m_chatModule;
     ContactsModule     *m_contactsModule;
     CommandModule      *m_commandModule;
+    RoomSpeakModule    *m_roomSpeakModule;
     ConversationModule *m_conversationModule;
     ActivityModule     *m_activityModule;
     IdentityModule     *m_identityModule;
@@ -193,6 +199,7 @@ private:
 
 
     VariableParser *m_variableParser;
+    SpeechDataStore *m_speechDataStore;
 
     MessageHandler  *m_messageHandler;
     CommandHandler  *m_commandHandler;
@@ -205,6 +212,7 @@ private:
     QXmppClient *m_xmppClient;
     QXmppMucManager *m_mucManager;
     QXmppMessageReceiptManager *m_receiptManager;
+    QXmppDiscoveryManager *m_discoveryManager;
 
 
     QString m_userJid;
@@ -212,6 +220,7 @@ private:
     bool m_userAutoconnect;
     QString m_userResource;
     int m_userPriority;
+    QString m_userServer;
 
     bool m_disconnectedManually;
 };
