@@ -24,14 +24,22 @@
 #include <QWidget>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
-#include <QListWidget>
+#include <QTableWidget>
+#include <QHeaderView>
 #include <QGroupBox>
 #include <QLineEdit>
 #include <QCheckBox>
+#include <QSpinBox>
 #include <QPushButton>
+#include <QDialogButtonBox>
 #include <QMessageBox>
 #include <QLabel>
 #include <QStackedWidget>
+#include <QResizeEvent>
+#include <QShowEvent>
+#include <QFontMetrics>
+#include <QChar>
+#include <QAction>
 
 #include <QDebug>
 
@@ -42,6 +50,7 @@
 #include "helpers.h"
 #include "chatwidget.h"
 #include "datafile.h"
+#include "roomspeakhandler.h"
 
 
 class RoomModule : public QWidget
@@ -55,11 +64,12 @@ public:
     void loadRoomInfo();
     void saveRoomInfo();
 
-    QString roomDescriptionLine(QString roomJid, QString nickname,
-                                bool hasPassword, bool autojoin);
+    void adjustRoomsTable();
 
-    QListWidgetItem *listItemFromJid(QString roomJid);
+    QTableWidgetItem *tableItemFromJid(QString roomJid);
     int stackIndexFromJid(QString roomJid);
+    QString allowedFeaturesString(bool commands, bool greetings,
+                                  bool casualSpeak, bool conversing);
 
     void joinRoom(QString roomJid, QString nickname, QString password);
     void leaveRoom(QString roomJid, QString reason);
@@ -68,7 +78,7 @@ public:
     bool newRoomIsValid(bool showErrors=false);
     void clearRoomDetails();
 
-    void toggleJoinLeaveButtons(QListWidgetItem *item);
+    void toggleJoinLeaveButtons(QTableWidgetItem *item);
 
 
 signals:
@@ -79,24 +89,36 @@ public slots:
     void editRoom();
     void updateRoom();
     void removeRoom();
+    void cancelEditMode();
+
+    void selectFirstRow();
+    void selectLastRow();
 
     void joinSelectedRoom();
     void leaveSelectedRoom();
     void changeNick();
 
-    void showRoomDetails(QListWidgetItem *item);
+    void showRoomDetails(int row);
     void toggleRoomDetails(bool state);
+    void onRoomDoubleClicked(QTableWidgetItem *item);
 
     void onRoomJoined(QString jid);
     void onRoomLeft(QString jid);
 
 
+protected:
+    virtual void showEvent(QShowEvent *event);
+    virtual void resizeEvent(QResizeEvent *event);
+
+
 private:
     QVBoxLayout *m_mainLayout;
-    QListWidget *m_roomListWidget;
+    QTableWidget *m_roomTableWidget;
+    QString m_keySymbolString;
 
     QHBoxLayout *m_buttonsLayout;
     QPushButton *m_addRoomButton;
+    QLabel *m_roomCountLabel;
     QPushButton *m_removeRoomButton;
 
     QGroupBox *m_detailsGroupbox;
@@ -107,17 +129,35 @@ private:
     QLineEdit *m_roomPasswordLineEdit;
     QCheckBox *m_autojoinCheckbox;
     QPushButton *m_editRoomButton;
-    QPushButton *m_updateRoomButton;
     QPushButton *m_joinButton;
     QPushButton *m_leaveButton;
+    QPushButton *m_updateRoomButton;
+    QPushButton *m_cancelButton;
+    QDialogButtonBox *m_updateCancelButtonBox;
+
+    QHBoxLayout *m_detailsExtraLayout;
+    QVBoxLayout *m_greetingsLayout;
+    QVBoxLayout *m_casualSpeakLayout;
+    QLabel *m_allowedToLabel;
+    QCheckBox *m_allowCommandsCheckbox;
+    QCheckBox *m_allowGreetingsCheckbox;
+    QSpinBox *m_greetingsSpinbox;
+    QCheckBox *m_allowCasualSpeakCheckbox; // Including activity-related
+    QSpinBox *m_casualSpeakSpinbox;
+    QCheckBox *m_allowConversingCheckbox;
 
 
     QStackedWidget *m_chatStackedWidget;
     QList<ChatWidget *> m_openedRooms;
+    QList<RoomSpeakHandler *> m_roomSpeakHandlers;
 
     QLabel *m_firstPageLabel;
 
 
+    QAction *m_goFirstAction;
+    QAction *m_goLastAction;
+
+
     DataFile *m_dataFile;
 
     QXmppMucManager *m_mucManager;
