@@ -42,11 +42,15 @@ public:
 
     QString getParsed(QString originalString);
 
+    bool checkSyntax(QString stringToTest,
+                     QStringList extraSubstitutions=QStringList());
+    QString getLastCheckError();
 
 
 private:
     QString m_ownNickname;
 
+    QString m_lastCheckError;
 };
 
 #endif // VARIABLEPARSER_H
