@@ -270,10 +270,6 @@
         <source>Available commands</source>
         <translation>Ordres disponibles</translation>
     </message>
-    <message>
-        <source>Command %1 requested without the right access level.</source>
-        <translation>S&apos;ha demanat la ordre %1 sense el nivell d&apos;accés adequat.</translation>
-    </message>
     <message>
         <source>I don&apos;t have a match for %1</source>
         <translation>No tinc cap coincidència per a %1</translation>
@@ -292,12 +288,20 @@
     </message>
     <message>
         <source>Started detached program successfully.</source>
-        <translation type="unfinished">S&apos;ha iniciat correctament el programa, de forma independent.</translation>
+        <translation>S&apos;ha iniciat correctament el programa, de forma independent.</translation>
     </message>
     <message>
         <source>I need a parameter for the query:</source>
         <translation>Necessito un paràmetre per la consulta:</translation>
     </message>
+    <message>
+        <source>Command %1 requested by %2 in room %3 without the right access level.</source>
+        <translation>%2 ha demanat la ordre %1 a la sala %3 sense el nivell d&apos;accés adequat.</translation>
+    </message>
+    <message>
+        <source>Command %1 requested by %2 without the right access level.</source>
+        <translation>%2 ha demanat la ordre %1 sense el nivell d&apos;accés adequat.</translation>
+    </message>
 </context>
 <context>
     <name>CommandModule</name>
@@ -472,10 +476,6 @@ La codificació de l&apos;arxiu hauria de ser UTF-8.</translation>
         <source>Launch the program independently</source>
         <translation>Executar el programa independentment</translation>
     </message>
-    <message>
-        <source>The name, without the prefix</source>
-        <translation>El nom, sense el prefix</translation>
-    </message>
     <message>
         <source>Error: There is already a command in the list with this name.</source>
         <translation>Error: Ja hi ha una ordre a la llista amb aquest nom.</translation>
@@ -523,6 +523,19 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Explanation shown to users with the %1 command</source>
         <translation>Explicació que es mostrarà als usuaris amb la ordre %1</translation>
     </message>
+    <message>
+        <source>The name, without the prefix or any spaces</source>
+        <translation type="vanished">El nom, sense el prefix o espais</translation>
+    </message>
+    <message>
+        <source>The command name can&apos;t contain spaces.</source>
+        <translation>El nom de la ordre no pot tenir espais.</translation>
+    </message>
+    <message>
+        <source>The name, without the prefix or any spaces</source>
+        <comment>Referring to the command&apos;s name/trigger</comment>
+        <translation>El nom, sense el prefix o espais</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -587,6 +600,38 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Program configuration saved.</source>
         <translation>S&apos;ha guardat la configuració del programa.</translation>
     </message>
+    <message>
+        <source>Select...</source>
+        <translation>Seleccionar...</translation>
+    </message>
+    <message>
+        <source>Use a custom icon</source>
+        <translation>Utilitzar una icona personalitzada</translation>
+    </message>
+    <message>
+        <source>Invalid icon</source>
+        <translation>Icona no vàlida</translation>
+    </message>
+    <message>
+        <source>The selected image is not valid.</source>
+        <translation>La imatge seleccionada no és vàlida.</translation>
+    </message>
+    <message>
+        <source>Icon file %1 does not exist</source>
+        <translation>L&apos;arxiu de icona %1 no existeix</translation>
+    </message>
+    <message>
+        <source>Select custom icon</source>
+        <translation>Selecciona una icona personalitzada</translation>
+    </message>
+    <message>
+        <source>Image files</source>
+        <translation>Arxius d&apos;imatge</translation>
+    </message>
+    <message>
+        <source>All files</source>
+        <translation>Tots els arxius</translation>
+    </message>
 </context>
 <context>
     <name>ConnectionDialog</name>
@@ -739,6 +784,21 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Status Message:</source>
         <translation>Missatge d&apos;estat:</translation>
     </message>
+    <message>
+        <source>Uptime:</source>
+        <translatorcomment>Temps connectat? Temps d&apos;activitat?</translatorcomment>
+        <translation type="unfinished">Temps de connexió:</translation>
+    </message>
+    <message>
+        <source>Rooms:</source>
+        <translation>Sales:</translation>
+    </message>
+    <message>
+        <source>%1 joined, out of %2 configured</source>
+        <comment>Number of rooms joined and configured</comment>
+        <translatorcomment>Meh...</translatorcomment>
+        <translation>S&apos;ha entrat a %1, de %2 configurades</translation>
+    </message>
 </context>
 <context>
     <name>HelpWidget</name>
@@ -808,7 +868,7 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
     </message>
     <message>
         <source>In addition, syntax like %1 can be used to insert one out of several choices at random, at any desired point in the string.</source>
-        <translation>A més a més, es pot utilitzar sintaxi com %1 per insertar una de entre diverses possibilitats a l&apos;atzar, a qualsevol punt desitjat a la cadena de text.</translation>
+        <translation>A més a més, es pot utilitzar sintaxi com %1 per inserir una de entre diverses possibilitats a l&apos;atzar, a qualsevol punt desitjat a la cadena de text.</translation>
     </message>
     <message>
         <source>You can use the --config parameter (or -c) to run the program with a different configuration. This way, you can run two instances of AkariXB at the same time, with different accounts, different rooms configured, using a different command prefix, etc.</source>
@@ -866,6 +926,10 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>If the access level for the command is not set for everyone, only users listed in the administrators list in the Program Configuration window will be able to use that command.</source>
         <translation>Si el nivell d&apos;accés per la ordre no està establert per tothom, només els usuaris que es trobin a la llista d&apos;administradors a la finestra de Configuració del programa podran utilitzar aquesta ordre.</translation>
     </message>
+    <message>
+        <source>The nickname of the bot, as specified in the Identity module.</source>
+        <translation>El sobrenom del bot, tal com s&apos;especifica al mòdul Identitat.</translation>
+    </message>
 </context>
 <context>
     <name>IdentityModule</name>
@@ -891,6 +955,10 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Identity data has not been defined yet.</source>
         <translation>Les dades d&apos;identitat encara no s&apos;han definit.</translation>
     </message>
+    <message>
+        <source>Date of Birth</source>
+        <translation>Data de naixement</translation>
+    </message>
 </context>
 <context>
     <name>LogModule</name>
@@ -1010,7 +1078,7 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
     </message>
     <message>
         <source>Account is not configured</source>
-        <translation>El compte no està configurat.</translation>
+        <translation>El compte no està configurat</translation>
     </message>
     <message>
         <source>Data directory created: %1</source>
@@ -1134,6 +1202,15 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Settings file in use: %1</source>
         <translation>Arxiu de configuració en ús: %1</translation>
     </message>
+    <message>
+        <source>Room Speech</source>
+        <translatorcomment>Meh...</translatorcomment>
+        <translation type="unfinished">Conversa en sales</translation>
+    </message>
+    <message>
+        <source>Received version information from %1:</source>
+        <translation>S&apos;ha rebut la informació de versió de %1:</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -1187,11 +1264,6 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Room Details</source>
         <translation>Detalls de la sala</translation>
     </message>
-    <message>
-        <source>%1 as %2</source>
-        <translatorcomment>FIXME: meh... aquesta canviarà a la 0.8</translatorcomment>
-        <translation>%1 com a %2</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Error</translation>
@@ -1263,6 +1335,112 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Do you want to remove room %1 from your list?</source>
         <translation>Vols treure la sala %1 de la teva llista?</translation>
     </message>
+    <message>
+        <source>Allowed</source>
+        <comment>Column header for features allowed</comment>
+        <translation>Permès</translation>
+    </message>
+    <message>
+        <source>Allowed to:</source>
+        <translation>Es permet:</translation>
+    </message>
+    <message>
+        <source>Reply to commands</source>
+        <translation>Respondre a ordres</translation>
+    </message>
+    <message>
+        <source>Greet people</source>
+        <translation>Saludar a gent</translation>
+    </message>
+    <message>
+        <source>Speak casually</source>
+        <translatorcomment>Meh...</translatorcomment>
+        <translation type="obsolete">Parlar de forma casual</translation>
+    </message>
+    <message>
+        <source>Converse</source>
+        <translation>Conversar</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Cancel·lar</translation>
+    </message>
+    <message numerus="yes">
+        <source>%Ln room(s)</source>
+        <translation>
+            <numerusform>1 sala</numerusform>
+            <numerusform>%Ln sales</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>There is already a room in the list with this address, in row %1.</source>
+        <translation>Ja hi ha una sala a la llista amb aquesta adreça, a la fila %1.</translation>
+    </message>
+    <message>
+        <source>Speak casually</source>
+        <comment>Casually as in, from time to time</comment>
+        <translation>Parlar de forma casual</translation>
+    </message>
+</context>
+<context>
+    <name>RoomSpeakModule</name>
+    <message>
+        <source>Greetings</source>
+        <translation>Salutacions</translation>
+    </message>
+    <message>
+        <source>Casual speak</source>
+        <translation type="unfinished">Parlar casualment</translation>
+    </message>
+    <message>
+        <source>Reactions to words</source>
+        <translation>Reaccions a paraules</translation>
+    </message>
+    <message>
+        <source>Sentences used to greet people who enter a chatroom.</source>
+        <translation>Frases utilitzades per saludar a les persones que entren a les sales de xat.</translation>
+    </message>
+    <message>
+        <source>The %1 variable can be used to insert their names in the sentences.</source>
+        <translation>La variable %1 es pot utilitzar per inserir els seus noms a les frases.</translation>
+    </message>
+    <message>
+        <source>Example:</source>
+        <translation>Exemple:</translation>
+    </message>
+    <message>
+        <source>Documentation for Perl regular expressions</source>
+        <translation>Documentació d&apos;expressions regulars de Perl</translation>
+    </message>
+    <message>
+        <source>Sentences to be sent to chatrooms at random intervals.</source>
+        <translation>Frases per a enviar a les sales de xat a intervals aleatoris.</translation>
+    </message>
+    <message>
+        <source>Regular expressions to be matched against messages coming from the chatrooms, and possible messages to send in response.</source>
+        <translation type="unfinished">Expressions regulars amb les que comparar els missatges provinents de les sales de xat, i possibles missatges per enviar en resposta.</translation>
+    </message>
+</context>
+<context>
+    <name>RoomSpeakTab</name>
+    <message>
+        <source>&amp;Save</source>
+        <translation>&amp;Guardar</translation>
+    </message>
+    <message numerus="yes">
+        <source>Loaded %Ln sentence(s) of type %1.</source>
+        <translation>
+            <numerusform>S&apos;ha carregat 1 frase de tipus %1.</numerusform>
+            <numerusform>S&apos;han carregat %Ln frases de tipus %1.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved %Ln sentence(s) of type %1.</source>
+        <translation>
+            <numerusform>S&apos;ha guardat 1 frase de tipus %1.</numerusform>
+            <numerusform>S&apos;han guardat %Ln frases de tipus %1.</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>StringListWidget</name>
@@ -1278,18 +1456,6 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Update the text for this item</source>
         <translation>Actualitza el text d&apos;aquest element</translation>
     </message>
-    <message>
-        <source>Add an item to the list</source>
-        <translation>Afegir un element a la llista</translation>
-    </message>
-    <message>
-        <source>Edit the selected item (you can also double-click it)</source>
-        <translation>Editar l&apos;element seleccionat (també li pots fer doble clic)</translation>
-    </message>
-    <message>
-        <source>Remove the selected item</source>
-        <translation>Treure l&apos;element seleccionat</translation>
-    </message>
     <message>
         <source>Update the definition of the item</source>
         <translation>Actualitzar la definició de l&apos;element</translation>
@@ -1302,5 +1468,68 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Error: There is already an item in the list with the text %1, and this list does not allow duplicates.</source>
         <translation>Error: Ja hi ha un element a la llista amb el text %1, i aquesta llista no permet duplicats.</translation>
     </message>
+    <message>
+        <source>Edit the selected item (you can also double-click it or press F2/Enter)</source>
+        <translation>Editar l&apos;element seleccionat (també li pots fer doble clic o prémer F2/Intro)</translation>
+    </message>
+    <message>
+        <source>Item text is not valid</source>
+        <translation>El text de l&apos;element no es vàlid</translation>
+    </message>
+    <message>
+        <source>Modify text</source>
+        <translation>Modifica el text</translation>
+    </message>
+    <message>
+        <source>Add an item to the list (you can also press the Insert key)</source>
+        <translation>Afegir un element a la llista (també pots prémer la tecla Insert)</translation>
+    </message>
+    <message>
+        <source>String</source>
+        <translation>Cadena</translation>
+    </message>
+    <message>
+        <source>Regular Expression</source>
+        <translation>Expressió regular</translation>
+    </message>
+    <message>
+        <source>Tags</source>
+        <translation>Etiquetes</translation>
+    </message>
+    <message>
+        <source>Search...</source>
+        <translation>Cercar...</translation>
+    </message>
+    <message>
+        <source>Show All</source>
+        <translation>Mostrar-ho tot</translation>
+    </message>
+    <message>
+        <source>Remove the selected item (you can also press Shift+Delete)</source>
+        <translation>Treure l&apos;element seleccionat (també pots prémer Majúscules+Supr)</translation>
+    </message>
+    <message>
+        <source>Regular expression is not valid</source>
+        <translation>L&apos;expressió regular no és vàlida</translation>
+    </message>
+    <message>
+        <source>Syntax error at position %1:</source>
+        <translation>Error de sintaxi a la posició %1:</translation>
+    </message>
+</context>
+<context>
+    <name>VariableParser</name>
+    <message>
+        <source>Unbalanced braces: %1 opening and %2 closing</source>
+        <translation type="unfinished">Claus descompensades: %1 que obren i %2 que tanquen</translation>
+    </message>
+    <message>
+        <source>This substitution is unknown, or not valid in this context: %1</source>
+        <translation>Aquesta substitució és desconeguda, o no és vàlida en aquest context: %1</translation>
+    </message>
+    <message>
+        <source>Syntax error:</source>
+        <translation>Error de sintaxi:</translation>
+    </message>
 </context>
 </TS>
