@@ -271,10 +271,6 @@
         <source>Available commands</source>
         <translation>Comandos disponibles</translation>
     </message>
-    <message>
-        <source>Command %1 requested without the right access level.</source>
-        <translation>Se ha solicitado el comando %1 sin el nivel de acceso adecuado.</translation>
-    </message>
     <message>
         <source>I don&apos;t have a match for %1</source>
         <translation>No tengo ninguna coincidencia para %1</translation>
@@ -299,6 +295,14 @@
         <source>I need a parameter for the query:</source>
         <translation>Necesito un parámetro para la consulta:</translation>
     </message>
+    <message>
+        <source>Command %1 requested by %2 in room %3 without the right access level.</source>
+        <translation>%2 ha solicitado el comando %1 en la sala %3, sin el nivel de acceso adecuado.</translation>
+    </message>
+    <message>
+        <source>Command %1 requested by %2 without the right access level.</source>
+        <translation>%2 ha solicitado el comando %1 sin el nivel de acceso adecuado.</translation>
+    </message>
 </context>
 <context>
     <name>CommandModule</name>
@@ -473,10 +477,6 @@ La codificación del archivo debe ser UTF-8.</translation>
         <source>Launch the program independently</source>
         <translation>Lanzar el programa de forma independiente</translation>
     </message>
-    <message>
-        <source>The name, without the prefix</source>
-        <translation>El nombre, sin el prefijo</translation>
-    </message>
     <message>
         <source>Error: There is already a command in the list with this name.</source>
         <translation>Error: Ya hay un comando en la lista con este nombre.</translation>
@@ -524,6 +524,19 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Explanation shown to users with the %1 command</source>
         <translation>Explicación mostrada a los usuarios con el comando %1</translation>
     </message>
+    <message>
+        <source>The name, without the prefix or any spaces</source>
+        <translation type="vanished">El nombre, sin el prefijo ni espacios</translation>
+    </message>
+    <message>
+        <source>The command name can&apos;t contain spaces.</source>
+        <translation>El nombre del comando no puede contener espacios.</translation>
+    </message>
+    <message>
+        <source>The name, without the prefix or any spaces</source>
+        <comment>Referring to the command&apos;s name/trigger</comment>
+        <translation>El nombre, sin el prefijo ni espacios</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -588,6 +601,38 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Program configuration saved.</source>
         <translation>Se ha guardado la configuración del programa.</translation>
     </message>
+    <message>
+        <source>Select...</source>
+        <translation>Seleccionar...</translation>
+    </message>
+    <message>
+        <source>Use a custom icon</source>
+        <translation>Usar un icono personalizado</translation>
+    </message>
+    <message>
+        <source>Invalid icon</source>
+        <translation>Icono no válido</translation>
+    </message>
+    <message>
+        <source>The selected image is not valid.</source>
+        <translation>La imagen seleccionada no es válida.</translation>
+    </message>
+    <message>
+        <source>Icon file %1 does not exist</source>
+        <translation>El archivo de icono %1 no existe</translation>
+    </message>
+    <message>
+        <source>Select custom icon</source>
+        <translation>Selecciona un icono personalizado</translation>
+    </message>
+    <message>
+        <source>Image files</source>
+        <translation>Archivos de imagen</translation>
+    </message>
+    <message>
+        <source>All files</source>
+        <translation>Todos los archivos</translation>
+    </message>
 </context>
 <context>
     <name>ConnectionDialog</name>
@@ -740,6 +785,20 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Status Message:</source>
         <translation>Mensaje de estado:</translation>
     </message>
+    <message>
+        <source>Uptime:</source>
+        <translatorcomment>Otras opciones serian: &quot;Tiempo de conexión:&quot; o &quot;Tiempo de actividad:&quot;</translatorcomment>
+        <translation type="unfinished">Tiempo conectado:</translation>
+    </message>
+    <message>
+        <source>Rooms:</source>
+        <translation>Salas:</translation>
+    </message>
+    <message>
+        <source>%1 joined, out of %2 configured</source>
+        <comment>Number of rooms joined and configured</comment>
+        <translation>Se ha entrado en %1, de %2 configuradas</translation>
+    </message>
 </context>
 <context>
     <name>HelpWidget</name>
@@ -867,6 +926,10 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>If the access level for the command is not set for everyone, only users listed in the administrators list in the Program Configuration window will be able to use that command.</source>
         <translation>Si el nivel de acceso del comando no está establecido para todo el mundo, solo los usuarios presentes en la lista de administradores de la ventana Configuración del programa podrán usar ese comando.</translation>
     </message>
+    <message>
+        <source>The nickname of the bot, as specified in the Identity module.</source>
+        <translation>El apodo del bot, como se especifica en el módulo Identidad.</translation>
+    </message>
 </context>
 <context>
     <name>IdentityModule</name>
@@ -881,7 +944,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     <message>
         <source>Loaded identity data for %1.</source>
         <comment>%1 is a nickname</comment>
-        <translation>Datos de identidad cargados para %1.</translation>
+        <translation>Se han cargado los datos de identidad para %1.</translation>
     </message>
     <message>
         <source>Saved identity data for %1.</source>
@@ -892,6 +955,10 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Identity data has not been defined yet.</source>
         <translation>Los datos de identidad aún no se han definido.</translation>
     </message>
+    <message>
+        <source>Date of Birth</source>
+        <translation>Fecha de nacimiento</translation>
+    </message>
 </context>
 <context>
     <name>LogModule</name>
@@ -1134,6 +1201,15 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Settings file in use: %1</source>
         <translation>Archivo de configuración en uso: %1</translation>
     </message>
+    <message>
+        <source>Room Speech</source>
+        <translatorcomment>No me termina de gustar, pero de momento así se queda.</translatorcomment>
+        <translation type="unfinished">Conversación en salas</translation>
+    </message>
+    <message>
+        <source>Received version information from %1:</source>
+        <translation>Se ha recibido versión de información de %1:</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -1187,11 +1263,6 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Room Details</source>
         <translation>Detalles de la sala</translation>
     </message>
-    <message>
-        <source>%1 as %2</source>
-        <translatorcomment>FIXME: meh... Esto desaparecerá cuando la lista de salas pase a ser una tabla en condiciones.</translatorcomment>
-        <translation type="unfinished">%1 como %2</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Error</translation>
@@ -1263,6 +1334,113 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Do you want to remove room %1 from your list?</source>
         <translation>¿Quieres quitar la sala %1 de la lista?</translation>
     </message>
+    <message>
+        <source>Allowed</source>
+        <comment>Column header for features allowed</comment>
+        <translation>Permitido</translation>
+    </message>
+    <message>
+        <source>Allowed to:</source>
+        <translation>Se permite:</translation>
+    </message>
+    <message>
+        <source>Reply to commands</source>
+        <translation>Responder a comandos</translation>
+    </message>
+    <message>
+        <source>Greet people</source>
+        <translation>Saludar a gente</translation>
+    </message>
+    <message>
+        <source>Speak casually</source>
+        <translatorcomment>............. meh</translatorcomment>
+        <translation type="obsolete">Hablar de forma casual</translation>
+    </message>
+    <message>
+        <source>Converse</source>
+        <translation>Conversar</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+    <message numerus="yes">
+        <source>%Ln room(s)</source>
+        <translation>
+            <numerusform>1 sala</numerusform>
+            <numerusform>%Ln salas</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>There is already a room in the list with this address, in row %1.</source>
+        <translation>Ya hay una sala en la lista con esta dirección, en la fila %1.</translation>
+    </message>
+    <message>
+        <source>Speak casually</source>
+        <comment>Casually as in, from time to time</comment>
+        <translation>Hablar de forma casual</translation>
+    </message>
+</context>
+<context>
+    <name>RoomSpeakModule</name>
+    <message>
+        <source>Greetings</source>
+        <translation>Saludos</translation>
+    </message>
+    <message>
+        <source>Casual speak</source>
+        <translation type="unfinished">Hablar casualmente</translation>
+    </message>
+    <message>
+        <source>Reactions to words</source>
+        <translation>Reacciones a palabras</translation>
+    </message>
+    <message>
+        <source>Sentences used to greet people who enter a chatroom.</source>
+        <translation>Frases utilizadas para saludar a las personas que entran a las salas de charla.</translation>
+    </message>
+    <message>
+        <source>The %1 variable can be used to insert their names in the sentences.</source>
+        <translation>La variable %1 se puede usar para insertar sus nombres en las frases.</translation>
+    </message>
+    <message>
+        <source>Example:</source>
+        <translation>Ejemplo:</translation>
+    </message>
+    <message>
+        <source>Documentation for Perl regular expressions</source>
+        <translation>Documentación de expresiones regulares de Perl</translation>
+    </message>
+    <message>
+        <source>Sentences to be sent to chatrooms at random intervals.</source>
+        <translation>Frases para enviar a las salas de charla a intervalos aleatorios.</translation>
+    </message>
+    <message>
+        <source>Regular expressions to be matched against messages coming from the chatrooms, and possible messages to send in response.</source>
+        <translatorcomment>Meh....</translatorcomment>
+        <translation type="unfinished">Expresiones regulares con las que comparar los mensajes provenientes de las salas de charla, y posibles mensajes para enviar en respuesta.</translation>
+    </message>
+</context>
+<context>
+    <name>RoomSpeakTab</name>
+    <message>
+        <source>&amp;Save</source>
+        <translation>&amp;Guardar</translation>
+    </message>
+    <message numerus="yes">
+        <source>Loaded %Ln sentence(s) of type %1.</source>
+        <translation>
+            <numerusform>Se ha cargado una frase de tipo %1.</numerusform>
+            <numerusform>Se han cargado %Ln frases de tipo %1.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved %Ln sentence(s) of type %1.</source>
+        <translation>
+            <numerusform>Se ha guardado una frase de tipo %1.</numerusform>
+            <numerusform>Se han guardado %Ln frases de tipo %1.</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>StringListWidget</name>
@@ -1278,18 +1456,6 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Update the text for this item</source>
         <translation>Actualiza el texto de este elemento</translation>
     </message>
-    <message>
-        <source>Add an item to the list</source>
-        <translation>Añadir un elemento a la lista</translation>
-    </message>
-    <message>
-        <source>Edit the selected item (you can also double-click it)</source>
-        <translation>Editar el elemento seleccionado (también puedes hacer doble clic en él)</translation>
-    </message>
-    <message>
-        <source>Remove the selected item</source>
-        <translation>Quitar el elemento seleccionado</translation>
-    </message>
     <message>
         <source>Update the definition of the item</source>
         <translation>Actualizar la definición de este elemento</translation>
@@ -1302,5 +1468,68 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Error: There is already an item in the list with the text %1, and this list does not allow duplicates.</source>
         <translation>Error: Ya hay un elemento en la lista con el texto %1, y esta lista no permite duplicados.</translation>
     </message>
+    <message>
+        <source>Edit the selected item (you can also double-click it or press F2/Enter)</source>
+        <translation>Editar el elemento seleccionado (también puedes hacer doble clic en él, o pulsar F2/Intro)</translation>
+    </message>
+    <message>
+        <source>Item text is not valid</source>
+        <translation>El texto del elemento no es válido</translation>
+    </message>
+    <message>
+        <source>Modify text</source>
+        <translation>Modifica el texto</translation>
+    </message>
+    <message>
+        <source>Add an item to the list (you can also press the Insert key)</source>
+        <translation>Añadir un elemento a la lista (también puedes pulsar la tecla Insert)</translation>
+    </message>
+    <message>
+        <source>String</source>
+        <translation>Cadena</translation>
+    </message>
+    <message>
+        <source>Regular Expression</source>
+        <translation>Expresión regular</translation>
+    </message>
+    <message>
+        <source>Tags</source>
+        <translation>Etiquetas</translation>
+    </message>
+    <message>
+        <source>Search...</source>
+        <translation>Buscar...</translation>
+    </message>
+    <message>
+        <source>Show All</source>
+        <translation>Mostrar todo</translation>
+    </message>
+    <message>
+        <source>Remove the selected item (you can also press Shift+Delete)</source>
+        <translation>Quitar el elemento seleccionado (también puedes pulsar Mayúsculas+Supr)</translation>
+    </message>
+    <message>
+        <source>Regular expression is not valid</source>
+        <translation>L&apos;expressió regular no</translation>
+    </message>
+    <message>
+        <source>Syntax error at position %1:</source>
+        <translation>Error de sintaxis en la posición %1:</translation>
+    </message>
+</context>
+<context>
+    <name>VariableParser</name>
+    <message>
+        <source>Unbalanced braces: %1 opening and %2 closing</source>
+        <translation type="unfinished">Llaves descompensadas: %1 que abren y %2 que cierran</translation>
+    </message>
+    <message>
+        <source>This substitution is unknown, or not valid in this context: %1</source>
+        <translation>Esta sustitución es desconocida, o no es válida en este contexto: %1</translation>
+    </message>
+    <message>
+        <source>Syntax error:</source>
+        <translation>Error de sintaxis:</translation>
+    </message>
 </context>
 </TS>
